@@ -30,6 +30,7 @@ class ArtistArt:
         """
             Init artist artwork
         """
+        self._ext = "jpg"
         try:
             self.__migrate_old_dir()
         except Exception as e:
@@ -99,13 +100,14 @@ class ArtistArt:
             w = width
             h = height
         filename = self.encode_artist_name(artist)
-        cache_path_jpg = "%s/%s_%s_%s.jpg" % (CACHE_PATH, filename, w, h)
+        cache_filepath = "%s/%s_%s_%s.%s" % (CACHE_PATH, filename,
+                                             w, h, self._ext)
         pixbuf = None
         try:
             # Look in cache
-            f = Gio.File.new_for_path(cache_path_jpg)
+            f = Gio.File.new_for_path(cache_filepath)
             if not behaviour & ArtBehaviour.NO_CACHE and f.query_exists():
-                pixbuf = GdkPixbuf.Pixbuf.new_from_file(cache_path_jpg)
+                pixbuf = GdkPixbuf.Pixbuf.new_from_file(cache_filepath)
                 if optimized_blur:
                     pixbuf = self.load_behaviour(pixbuf, None,
                                                  width, height, behaviour)
@@ -120,7 +122,7 @@ class ArtistArt:
                 else:
                     self.cache_artist_artwork(artist)
                     return None
-                pixbuf = self.load_behaviour(pixbuf, cache_path_jpg,
+                pixbuf = self.load_behaviour(pixbuf, cache_filepath,
                                              width, height, behaviour)
             return pixbuf
         except Exception as e:
