@@ -15,7 +15,7 @@ from gi.repository import GObject, Gio, GLib, GdkPixbuf
 from PIL import Image, ImageFilter
 
 from lollypop.define import ArtSize, App, ArtBehaviour
-from lollypop.define import STORE_PATH
+from lollypop.define import ALBUMS_PATH
 from lollypop.logger import Logger
 
 
@@ -28,7 +28,6 @@ class BaseArt(GObject.GObject):
         "album-artwork-changed": (GObject.SignalFlags.RUN_FIRST, None, (int,)),
         "artist-artwork-changed": (GObject.SignalFlags.RUN_FIRST,
                                    None, (str,)),
-        "radio-artwork-changed": (GObject.SignalFlags.RUN_FIRST, None, (str,)),
         "uri-artwork-found": (GObject.SignalFlags.RUN_FIRST, None,
                               (GObject.TYPE_PYOBJECT,)),
     }
@@ -96,7 +95,7 @@ class BaseArt(GObject.GObject):
         """
         value = App().settings.get_value("cover-size").get_int32()
         # Check value as user can enter bad value via dconf
-        if value < 170 or value > 300:
+        if value < 50 or value > 400:
             value = 200
         ArtSize.BIG = value
         ArtSize.BANNER = int(ArtSize.BIG * 150 / 200)
@@ -108,7 +107,7 @@ class BaseArt(GObject.GObject):
             @param filename as str
         """
         try:
-            filepath = STORE_PATH + "/" + filename + ".jpg"
+            filepath = "%s/%s.%s" % (ALBUMS_PATH, filename, self._ext)
             f = Gio.File.new_for_path(filepath)
             if f.query_exists():
                 f.delete()
@@ -159,9 +158,7 @@ class BaseArt(GObject.GObject):
         height = pixbuf.get_height()
         aspect = width / height
         wanted_aspect = wanted_width / wanted_height
-        if width == height:
-            new_pixbuf = pixbuf
-        elif aspect > wanted_aspect:
+        if aspect > wanted_aspect:
             new_width = height * wanted_aspect
             offset = (width - new_width)
             new_pixbuf = pixbuf.new_subpixbuf(offset / 2,
