@@ -68,6 +68,7 @@ class CollectionScanner(GObject.GObject, TagReader):
         self.__thread = None
         self.__tags = {}
         self.__items = []
+        self.__notified_ids = []
         self.__pending_new_artist_ids = []
         self.__history = History()
         self.__progress_total = 1
@@ -143,6 +144,9 @@ class CollectionScanner(GObject.GObject, TagReader):
                                                item.album_synced,
                                                item.album_mtime,
                                                item.storage_type)
+        if item.year is not None:
+            App().albums.set_year(item.album_id, item.year)
+            App().albums.set_timestamp(item.album_id, item.timestamp)
 
     def save_track(self, item):
         """
@@ -210,8 +214,11 @@ class CollectionScanner(GObject.GObject, TagReader):
             App().albums.set_artist_ids(item.album_id, item.album_artist_ids)
         # Set artist ids based on content
         else:
-            new_album_artist_ids = App().albums.calculate_artist_ids(
-                item.album_id, self.__disable_compilations)
+            if item.compilation:
+                new_album_artist_ids = [Type.COMPILATIONS]
+            else:
+                new_album_artist_ids = App().albums.calculate_artist_ids(
+                    item.album_id, self.__disable_compilations)
             App().albums.set_artist_ids(item.album_id, new_album_artist_ids)
             # We handle artists already created by any previous save_track()
             item.new_album_artist_ids = []
@@ -231,9 +238,10 @@ class CollectionScanner(GObject.GObject, TagReader):
             App().albums.add_genre(item.album_id, genre_id)
         # Update year based on tracks
         year = App().tracks.get_year_for_album(item.album_id)
-        App().albums.set_year(item.album_id, year)
-        timestamp = App().tracks.get_timestamp_for_album(item.album_id)
-        App().albums.set_timestamp(item.album_id, timestamp)
+        if year is not None:
+            App().albums.set_year(item.album_id, year)
+            timestamp = App().tracks.get_timestamp_for_album(item.album_id)
+            App().albums.set_timestamp(item.album_id, timestamp)
         App().cache.clear_durations(item.album_id)
 
     def update_track(self, item):
@@ -278,9 +286,7 @@ class CollectionScanner(GObject.GObject, TagReader):
                                    album_loved, album_pop, album_rate,
                                    album_synced)
             App().tracks.remove(track_id)
-            # Force genre for album
             genre_ids = App().tracks.get_genre_ids(track_id)
-            App().albums.set_genre_ids(album_id, genre_ids)
             App().albums.clean()
             App().genres.clean()
             App().artists.clean()
@@ -298,6 +304,9 @@ class CollectionScanner(GObject.GObject, TagReader):
                         item.genre_ids.append(genre_id)
                 emit_signal(self, "updated", item, ScanUpdate.REMOVED)
             else:
+                # Force genre for album
+                genre_ids = App().tracks.get_album_genre_ids(album_id)
+                App().albums.set_genre_ids(album_id, genre_ids)
                 emit_signal(self, "updated", item, ScanUpdate.MODIFIED)
             return (track_pop, track_rate, track_ltime, album_mtime,
                     track_loved, album_loved, album_pop, album_rate)
@@ -317,6 +326,20 @@ class CollectionScanner(GObject.GObject, TagReader):
         """
         self.__thread = None
 
+    def reset_database(self):
+        """
+            Reset database
+        """
+        from lollypop.app_notification import AppNotification
+        App().window.container.progress.add(self)
+        App().window.container.progress.set_fraction(0, self)
+        self.__progress_fraction = 0
+        notification = AppNotification(_("Resetting database"), [], [])
+        notification.show()
+        App().window.container.add_overlay(notification)
+        notification.set_reveal_child(True)
+        App().task_helper.run(self.__reset_database)
+
     @property
     def inotify(self):
         """
@@ -328,6 +351,37 @@ class CollectionScanner(GObject.GObject, TagReader):
 #######################
 # PRIVATE             #
 #######################
+    def __reset_database(self):
+        """
+            Reset database
+        """
+        def update_ui():
+            App().window.container.go_home()
+            App().scanner.update(ScanType.FULL)
+        App().player.stop()
+        if App().ws_director.collection_ws is not None:
+            App().ws_director.collection_ws.stop()
+        uris = App().tracks.get_uris()
+        i = 0
+        SqlCursor.add(App().db)
+        SqlCursor.add(self.__history)
+        count = len(uris)
+        for uri in uris:
+            self.del_from_db(uri, True)
+            self.__update_progress(i, count, 0.01)
+            i += 1
+        App().tracks.del_persistent(False)
+        App().tracks.clean(False)
+        App().albums.clean(False)
+        App().artists.clean(False)
+        App().genres.clean(False)
+        App().cache.clear_table("duration")
+        SqlCursor.commit(App().db)
+        SqlCursor.remove(App().db)
+        SqlCursor.commit(self.__history)
+        SqlCursor.remove(self.__history)
+        GLib.idle_add(update_ui)
+
     def __update_progress(self, current, total, allowed_diff):
         """
             Update progress bar status
@@ -467,6 +521,7 @@ class CollectionScanner(GObject.GObject, TagReader):
             count = max(1, min(5, cpu_count() // 2))
             split_files = split_list(files, count)
             self.__tags = {}
+            self.__notified_ids = []
             self.__pending_new_artist_ids = []
             threads = []
             for files in split_files:
@@ -591,8 +646,6 @@ class CollectionScanner(GObject.GObject, TagReader):
             @return [CollectionItem]
         """
         items = []
-        notify_index = 0
-        previous_album_id = None
         for uri in list(self.__tags.keys()):
             # Handle a stop request
             if self.__thread is None:
@@ -605,15 +658,13 @@ class CollectionScanner(GObject.GObject, TagReader):
             self.__update_progress(self.__progress_count,
                                    self.__progress_total,
                                    0.001)
-            if previous_album_id != item.album_id:
-                self.__notify_ui(items[notify_index:])
-                notify_index = len(items)
-                previous_album_id = item.album_id
+            if item.album_id not in self.__notified_ids:
+                self.__notified_ids.append(item.album_id)
+                self.__notify_ui(item)
             del self.__tags[uri]
         # Handle a stop request
         if self.__thread is None:
             raise Exception("cancelled")
-        self.__notify_ui(items)
         return items
 
     def __save_streams_in_db(self, streams, storage_type):
@@ -630,22 +681,21 @@ class CollectionScanner(GObject.GObject, TagReader):
                                  None, "", "", parsed.netloc,
                                  parsed.netloc, "", False, 0, False, 0, 0, 0,
                                  None, 0, "", "", "", "", 1, 0, 0, 0, 0, 0,
-                                 False, 0, storage_type)
+                                 False, 0, False, storage_type)
             items.append(item)
             self.__progress_count += 1
         return items
 
-    def __notify_ui(self, items):
+    def __notify_ui(self, item):
         """
-            Notify UI based on current items
-            @param items as [CollectionItem]
+            Notify UI for item
+            @param items as CollectionItem
         """
         SqlCursor.commit(App().db)
-        for item in items:
-            if item.new_album:
-                emit_signal(self, "updated", item, ScanUpdate.ADDED)
-            else:
-                emit_signal(self, "updated", item, ScanUpdate.MODIFIED)
+        if item.new_album:
+            emit_signal(self, "updated", item, ScanUpdate.ADDED)
+        else:
+            emit_signal(self, "updated", item, ScanUpdate.MODIFIED)
 
     def __remove_old_tracks(self, uris, scan_type):
         """
@@ -715,11 +765,6 @@ class CollectionScanner(GObject.GObject, TagReader):
         if version != "":
             title += " (%s)" % version
         artists = self.get_artists(tags)
-        composers = self.get_composers(tags)
-        performers = self.get_performers(tags)
-        remixers = self.get_remixers(tags)
-        if remixers != "":
-            artists += ";%s" % remixers
         a_sortnames = self.get_artist_sortnames(tags)
         aa_sortnames = self.get_album_artist_sortnames(tags)
         album_artists = self.get_album_artists(tags)
@@ -738,28 +783,32 @@ class CollectionScanner(GObject.GObject, TagReader):
         if album_mtime == 0:
             album_mtime = track_mtime
         bpm = self.get_bpm(tags)
-        (year, timestamp) = self.get_original_year(tags)
+        compilation = self.get_compilation(tags)
+        year = None
+        if not App().settings.get_value("ignore-original-date"):
+            (year, timestamp) = self.get_original_year(tags)
         if year is None:
             (year, timestamp) = self.get_year(tags)
-
         # If no artists tag, use album artist
         if artists == "":
             artists = album_artists
-        # if artists is always null, no album artists too,
-        # use composer/performer
+        if App().settings.get_value("import-advanced-artist-tags"):
+            composers = self.get_composers(tags)
+            conductors = self.get_conductors(tags)
+            performers = self.get_performers(tags)
+            remixers = self.get_remixers(tags)
+            artists += ";%s" % performers if performers != "" else ""
+            artists += ";%s" % conductors if conductors != "" else ""
+            artists += ";%s" % composers if composers != "" else ""
+            artists += ";%s" % remixers if remixers != "" else ""
         if artists == "":
-            artists = performers
-            album_artists = composers
-            if artists == "":
-                artists = album_artists
-            if artists == "":
-                artists = _("Unknown")
+            artists = _("Unknown")
         return (title, artists, genres, a_sortnames, aa_sortnames,
                 album_artists, album_name, discname, album_loved, album_mtime,
                 album_synced, album_rate, album_pop, discnumber, year,
                 timestamp, mb_album_id, mb_track_id, mb_artist_id,
                 mb_album_artist_id, tracknumber, track_pop, track_rate, bpm,
-                track_mtime, track_ltime, track_loved, duration)
+                track_mtime, track_ltime, track_loved, duration, compilation)
 
     def __add2db(self, uri, name, artists,
                  genres, a_sortnames, aa_sortnames, album_artists, album_name,
@@ -767,7 +816,7 @@ class CollectionScanner(GObject.GObject, TagReader):
                  album_pop, discnumber, year, timestamp, mb_album_id,
                  mb_track_id, mb_artist_id, mb_album_artist_id,
                  tracknumber, track_pop, track_rate, bpm, track_mtime,
-                 track_ltime, track_loved, duration,
+                 track_ltime, track_loved, duration, compilation,
                  storage_type=StorageType.COLLECTION):
         """
             Add new file to DB
@@ -805,6 +854,7 @@ class CollectionScanner(GObject.GObject, TagReader):
                               track_ltime=track_ltime,
                               track_loved=track_loved,
                               duration=duration,
+                              compilation=compilation,
                               storage_type=storage_type)
         self.save_album(item)
         self.save_track(item)
