@@ -10,9 +10,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, GObject
+from gi.repository import Gtk, GLib, GObject, Handy
 
 from lollypop.define import App, Type
+from lollypop.utils import emit_signal
 from lollypop.view import View
 from lollypop.container_stack import StackContainer
 from lollypop.container_notification import NotificationContainer
@@ -21,12 +22,16 @@ from lollypop.container_playlists import PlaylistsContainer
 from lollypop.container_lists import ListsContainer
 from lollypop.container_views import ViewsContainer
 from lollypop.container_filter import FilterContainer
-from lollypop.container_adaptive import AdaptiveContainer
 from lollypop.progressbar import ProgressBar
 
 
+class Grid(Gtk.Grid):
+    def do_get_preferred_width(self):
+        return 200, 700
+
+
 class Container(Gtk.Overlay, NotificationContainer,
-                ScannerContainer, PlaylistsContainer, AdaptiveContainer,
+                ScannerContainer, PlaylistsContainer,
                 ListsContainer, ViewsContainer, FilterContainer):
     """
         Main view management
@@ -46,40 +51,37 @@ class Container(Gtk.Overlay, NotificationContainer,
         ScannerContainer.__init__(self)
         PlaylistsContainer.__init__(self)
         ViewsContainer.__init__(self)
-        self._main_widget = None
-        self._sidebar_two = None
-        self.__paned_position_id = None
+
+    def setup(self):
+        """
+            Setup container
+        """
+        self.__widget = Handy.Leaflet()
+        self.__widget.show()
+        self.__sub_widget = Handy.Leaflet()
+        self.__sub_widget.show()
         self.__focused_view = None
         self._stack = StackContainer()
-        self._stack.get_style_context().add_class("view")
         self._stack.show()
+        ListsContainer.__init__(self)
         self.__progress = ProgressBar()
         self.__progress.get_style_context().add_class("progress-bottom")
         self.__progress.set_property("valign", Gtk.Align.END)
         self.add_overlay(self.__progress)
         search_action = App().lookup_action("search")
         search_action.connect("activate", self.__on_search_activate)
-        self._main_widget = Gtk.Grid()
-        self._sidebar_two = Gtk.Paned.new(Gtk.Orientation.HORIZONTAL)
-        position = App().settings.get_value("paned-listview-width").get_int32()
-        self._sidebar_two.set_position(position)
-        self._sidebar_two.connect("notify::position", self.__on_paned_position)
-        self._sidebar_two.add2(self._stack)
-        self._main_widget.attach(self._sidebar_two, 0, 0, 1, 1)
-        position = App().settings.get_value(
-            "paned-listview-width").get_int32()
-        self._sidebar_two.set_position(position)
-        self._main_widget.show()
-        self._sidebar_two.show()
-        self._grid = Gtk.Grid()
-        self._grid.set_orientation(Gtk.Orientation.VERTICAL)
-        self._grid.set_column_spacing(2)
-        self._grid.show()
-        self.add(self._grid)
-        ListsContainer.__init__(self)
-        AdaptiveContainer.__init__(self)
+        self.__widget.add(self.sidebar)
+        self.__grid_view = Grid()
+        self.__grid_view.set_orientation(Gtk.Orientation.VERTICAL)
+        self.__grid_view.show()
+        self.__sub_widget.add(self.left_list)
+        self.__sub_widget.add(self.__grid_view)
+        self.__grid_view.attach(self._stack, 0, 0, 1, 1)
+        self.__widget.add(self.__sub_widget)
+        self.__widget.set_visible_child(self.__sub_widget)
+        self.__sub_widget.set_visible_child(self.__grid_view)
+        self.add(self.__widget)
         FilterContainer.__init__(self)
-        self._grid.add(self._main_widget)
 
     def stop(self):
         """
@@ -95,15 +97,7 @@ class Container(Gtk.Overlay, NotificationContainer,
         """
         view = self._stack.get_visible_child()
         if view is not None and view.args is not None:
-            from lollypop.view_artist_box import ArtistViewBox
-            from lollypop.view_artist_list import ArtistViewList
-            show_tracks = App().settings.get_value("show-artist-tracks")
-            if view.__class__ == ArtistViewBox and show_tracks:
-                cls = ArtistViewList
-            elif view.__class__ == ArtistViewList and not show_tracks:
-                cls = ArtistViewBox
-            else:
-                cls = view.__class__
+            cls = view.__class__
             new_view = cls(**view.args)
             new_view.populate()
             new_view.show()
@@ -119,13 +113,64 @@ class Container(Gtk.Overlay, NotificationContainer,
         """
         self.__focused_view = view
 
+    def go_home(self):
+        """
+            Go back to first page
+        """
+        self.__widget.set_visible_child(self.sidebar)
+        self._stack.clear()
+        emit_signal(self, "can-go-back-changed", False)
+
+    def go_back(self):
+        """
+            Go back in history
+        """
+        if self._stack.history.count > 0:
+            self._stack.go_back()
+        elif self.__sub_widget.get_folded() and\
+                self.__sub_widget.get_visible_child() != self.left_list:
+            self.__sub_widget.set_visible_child(self.left_list)
+            self._stack.clear()
+        elif self.__widget.get_folded() and\
+                self.__widget.get_visible_child() != self.sidebar:
+            self.__widget.set_visible_child(self.sidebar)
+            self._stack.clear()
+        emit_signal(self, "can-go-back-changed", self.can_go_back)
+
     @property
-    def main_widget(self):
+    def can_go_back(self):
+        """
+            True if can go back
+            @return bool
+        """
+        if self.__widget.get_folded():
+            return self.__widget.get_visible_child() != self._sidebar
+        else:
+            return self._stack.history.count > 0
+
+    @property
+    def widget(self):
         """
             Get main widget
+            @return Handy.Leaflet
+        """
+        return self.__widget
+
+    @property
+    def sub_widget(self):
+        """
+            Get sub widget
+            @return Handy.Leaflet
+        """
+        return self.__sub_widget
+
+    @property
+    def grid_view(self):
+        """
+            Get grid view
             @return Gtk.Grid
         """
-        return self._main_widget
+        return self.__grid_view
 
     @property
     def focused_view(self):
@@ -165,45 +210,11 @@ class Container(Gtk.Overlay, NotificationContainer,
 ############
 # PRIVATE  #
 ############
-    def __show_settings_dialog(self):
-        """
-            Show settings dialog if view exists in stack
-        """
-        from lollypop.view_settings import SettingsChildView
-        from lollypop.view_settings import SettingsView
-        if isinstance(self.view, SettingsChildView) or\
-                isinstance(self.view, SettingsView):
-            action = App().lookup_action("settings")
-            GLib.idle_add(action.activate,
-                          GLib.Variant("i", self.view.type))
-
     def __on_search_activate(self, action, variant):
         """
             @param action as Gio.SimpleAction
             @param variant as GLib.Variant
         """
-        if App().window.is_adaptive:
+        if App().window.folded:
             search = variant.get_string()
             App().window.container.show_view([Type.SEARCH], search)
-
-    def __on_paned_position(self, paned, param):
-        """
-            Save paned position
-            @param paned as Gtk.Paned
-            @param param as GParamSpec
-        """
-        def save_position():
-            self.__paned_position_id = None
-            position = paned.get_property(param.name)
-            # We do not want to save position while adaptive mode is set
-            if App().window is not None and App().window.is_adaptive:
-                return
-            App().settings.set_value("paned-listview-width",
-                                     GLib.Variant("i",
-                                                  position))
-        # We delay position saving
-        # Useful for adative mode where position get garbaged
-        if self.__paned_position_id is not None:
-            GLib.source_remove(self.__paned_position_id)
-        self.__paned_position_id = GLib.timeout_add(
-            1000, save_position)
