@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, Pango
+from gi.repository import Gtk, GLib
 
 from lollypop.logger import Logger
 from lollypop.selectionlist import SelectionList
@@ -18,7 +18,7 @@ from lollypop.define import App, Type, SelectionListMask, StorageType, ViewType
 from lollypop.shown import ShownLists
 from lollypop.helper_gestures import GesturesHelper
 from lollypop.view import View
-from lollypop.utils import emit_signal, get_default_storage_type, get_icon_name
+from lollypop.utils import emit_signal, get_default_storage_type
 
 
 class NoneView(View):
@@ -45,20 +45,15 @@ class ListsContainer:
         """
         self.__left_list = None
         self.__right_list = None
-
-    def setup_lists(self):
-        """
-            Setup container lists
-        """
         self._sidebar = SelectionList(SelectionListMask.SIDEBAR)
         self._sidebar.show()
         self._sidebar.listbox.connect("row-activated",
                                       self.__on_sidebar_activated)
         self._sidebar.connect("populated", self.__on_sidebar_populated)
-        self._main_widget.insert_column(0)
-        self._sidebar.set_mask(SelectionListMask.SIDEBAR)
         items = ShownLists.get(SelectionListMask.SIDEBAR)
         self._sidebar.populate(items)
+        self._stack.connect("set-sidebar-id", self.__on_set_sidebar_id)
+        self._stack.connect("set-selection-ids", self.__on_set_selection_ids)
 
     @property
     def sidebar(self):
@@ -75,9 +70,10 @@ class ListsContainer:
             @return SelectionList
         """
         if self.__left_list is None:
-            self.__left_list = SelectionList(SelectionListMask.VIEW)
+            self.__left_list = SelectionList(SelectionListMask.FASTSCROLL)
             self.__left_list.listbox.connect("row-activated",
                                              self.__on_left_list_activated)
+            self.__left_list.scrolled.set_size_request(300, -1)
         return self.__left_list
 
     @property
@@ -90,7 +86,7 @@ class ListsContainer:
             """
                 Hide right list on left list hidden
             """
-            if not App().window.is_adaptive:
+            if not App().window.folded:
                 self._hide_right_list()
 
         if self.__right_list is None:
@@ -101,8 +97,9 @@ class ListsContainer:
             style_context = self.__right_list_grid.get_style_context()
             style_context.add_class("left-gradient")
             style_context.add_class("opacity-transition-fast")
-            self.__right_list = SelectionList(SelectionListMask.VIEW)
+            self.__right_list = SelectionList(SelectionListMask.FASTSCROLL)
             self.__right_list.show()
+            self.__right_list.scrolled.set_size_request(250, -1)
             self.__gesture = GesturesHelper(
                 eventbox, primary_press_callback=self._hide_right_list)
             self.__right_list.listbox.connect("row-activated",
@@ -186,6 +183,7 @@ class ListsContainer:
             @param row as Gtk.ListBoxRow
         """
         Logger.debug("Container::__on_sidebar_activated()")
+        self.sub_widget.set_visible_child(self.grid_view)
         view = None
         focus_set = False
         selected_id = self._sidebar.selected_id
@@ -201,21 +199,28 @@ class ListsContainer:
             self._show_artists_list(self.left_list)
             self._hide_right_list()
             self.left_list.show()
+            self.widget.set_visible_child(self.sub_widget)
+            self.sub_widget.set_visible_child(self.left_list)
             self.set_focused_view(self.left_list)
             focus_set = True
         elif selected_id == Type.GENRES_LIST:
             self._show_genres_list(self.left_list)
             self._hide_right_list()
             self.left_list.show()
+            self.widget.set_visible_child(self.sub_widget)
+            self.sub_widget.set_visible_child(self.left_list)
             self.set_focused_view(self.left_list)
             focus_set = True
         else:
             self.left_list.hide()
             self.left_list.clear()
+            if self.widget.get_folded():
+                self.widget.set_visible_child(self.sub_widget)
+                self.sub_widget.set_visible_child(self.grid_view)
 
         storage_type = get_default_storage_type()
         if selected_id in [Type.ARTISTS_LIST, Type.GENRES_LIST] and not\
-                App().window.is_adaptive:
+                App().window.folded:
             view = NoneView()
             view.show()
         elif selected_id == Type.PLAYLISTS:
@@ -236,35 +241,6 @@ class ListsContainer:
             view = self._get_view_albums([selected_id], [], storage_type)
         elif selected_id == Type.WEB:
             view = self._get_view_albums([selected_id], [], StorageType.SAVED)
-        elif selected_id == Type.RADIOS:
-            message = """Radio support has been removed, sorry for that.
-            For a better radio player, use Shortwave:
-            """
-            view = View(StorageType.ALL, ViewType.DEFAULT)
-            image = Gtk.Image.new_from_icon_name(get_icon_name(Type.RADIOS),
-                                                 Gtk.IconSize.INVALID)
-            image.set_pixel_size(256)
-            image.set_property("expand", True)
-            style = image.get_style_context()
-            style.add_class("dim-label")
-            label = Gtk.Label()
-            style = label.get_style_context()
-            style.add_class("dim-label")
-            style.add_class("text-xx-large")
-            label.set_markup("%s" % GLib.markup_escape_text(message))
-            label.set_line_wrap_mode(Pango.WrapMode.WORD)
-            label.set_line_wrap(True)
-            button = Gtk.LinkButton.new(
-                "https://flathub.org/apps/details/de.haeckerfelix.Shortwave")
-            grid = Gtk.Grid()
-            grid.set_valign(Gtk.Align.CENTER)
-            grid.set_row_spacing(20)
-            grid.set_orientation(Gtk.Orientation.VERTICAL)
-            grid.add(image)
-            grid.add(label)
-            grid.add(button)
-            view.add_widget(grid)
-            view.show_all()
         elif selected_id == Type.YEARS:
             view = self._get_view_albums_decades(storage_type)
         elif selected_id == Type.GENRES:
@@ -278,14 +254,11 @@ class ListsContainer:
         if view is not None and view not in self._stack.get_children():
             view.show()
             self._stack.add(view)
-        # If we are in paned stack mode, show list two if wanted
-        if App().window.is_adaptive\
-                and selected_id in [Type.ARTISTS_LIST, Type.GENRES_LIST]:
-            self._stack.set_visible_child(self.left_list)
-        elif view is not None:
+        if view is not None:
             self._stack.set_visible_child(view)
             if not focus_set:
                 self.set_focused_view(view)
+        emit_signal(self, "can-go-back-changed", self.can_go_back)
 
     def __on_sidebar_populated(self, selection_list):
         """
@@ -297,8 +270,7 @@ class ListsContainer:
         else:
             startup_id = App().settings.get_value("startup-id").get_int32()
             if startup_id == -1:
-                if not App().window.is_adaptive:
-                    selection_list.select_first()
+                selection_list.select_first()
             else:
                 selection_list.select_ids([startup_id], True)
 
@@ -313,13 +285,14 @@ class ListsContainer:
         view = None
         storage_type = get_default_storage_type()
         if self.left_list.mask & SelectionListMask.GENRES:
-            if not App().window.is_adaptive:
+            if not App().window.folded:
                 view = self._get_view_albums(selected_ids, [], storage_type)
             self._show_artists_list(self.right_list, selected_ids)
             self._show_right_list()
         else:
             view = self._get_view_artists([], selected_ids, storage_type)
             self.set_focused_view(view)
+            self.sub_widget.set_visible_child(self.grid_view)
         if view is not None:
             view.show()
             self._stack.add(view)
@@ -339,6 +312,7 @@ class ListsContainer:
         self._stack.add(view)
         self._stack.set_visible_child(view)
         self.set_focused_view(view)
+        self.sub_widget.set_visible_child(self.grid_view)
 
     def __on_list_populated(self, selection_list):
         """
@@ -346,3 +320,46 @@ class ListsContainer:
             @param selection_list as SelectionList
         """
         selection_list.select_pending_ids()
+
+    def __on_set_sidebar_id(self, stack, sidebar_id):
+        """
+            Set sidebar id on container
+            @param stack as ContainerStack
+            @param sidebar_id as int
+        """
+        self._sidebar.select_ids([sidebar_id], False)
+
+    def __on_set_selection_ids(self, stack, selection_ids):
+        """
+            Set sidebar id and left/right list ids
+            @param stack as ContainerStack
+            @param selection_ids as {"left": [int], "right": [int])
+        """
+        # Restore left list
+        if selection_ids["left"]:
+            if self.left_list.selected_ids != selection_ids["left"]:
+                self.left_list.show()
+                if self.left_list.count == 0:
+                    self.left_list.set_selection_pending_ids(
+                        selection_ids["left"])
+                    if App().window.container.sidebar.selected_ids[0] ==\
+                            Type.GENRES_LIST:
+                        self._show_genres_list(self.left_list)
+                    else:
+                        self._show_artists_list(self.left_list)
+                else:
+                    self.left_list.select_ids(selection_ids["left"], False)
+                    self.left_list.show()
+        else:
+            self.left_list.hide()
+            self.left_list.clear()
+        # Restore right list
+        if selection_ids["right"]:
+            if self.right_list.selected_ids != selection_ids["right"]:
+                self.right_list.set_selection_pending_ids(
+                                        selection_ids["right"])
+                self._show_artists_list(self.right_list,
+                                        selection_ids["left"])
+                self._show_right_list()
+        else:
+            self._hide_right_list()
