@@ -11,6 +11,7 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from lollypop.define import App, SelectionListMask, Type, ScanUpdate
+from lollypop.utils import get_default_storage_type
 
 
 class ScannerContainer:
@@ -22,30 +23,28 @@ class ScannerContainer:
         """
             Init container
         """
-        App().scanner.connect("genre-updated", self.__on_genre_updated)
-        App().scanner.connect("artist-updated", self.__on_artist_updated)
+        App().scanner.connect("updated", self.__on_collection_updated)
 
 ############
 # PRIVATE  #
 ############
-    def __on_genre_updated(self, scanner, genre_id, scan_update):
+    def __handle_genre_update(self, genre_id, scan_update):
         """
             Add genre to genre list
-            @param scanner as CollectionScanner
             @param genre_id as int
             @param scan_update as ScanUpdate
         """
         if Type.GENRES_LIST in self.sidebar.selected_ids:
+            storage_type = get_default_storage_type()
             if scan_update == ScanUpdate.ADDED:
                 genre_name = App().genres.get_name(genre_id)
                 self.left_list.add_value((genre_id, genre_name, genre_name))
-            elif not App().artists.get_ids([genre_id]):
+            elif not App().artists.get_ids([genre_id], storage_type):
                 self.left_list.remove_value(genre_id)
 
-    def __on_artist_updated(self, scanner, artist_id, scan_update):
+    def __handle_artist_update(self, artist_id, scan_update):
         """
             Add/remove artist to/from list
-            @param scanner as CollectionScanner
             @param artist_id as int
             @param scan_update as ScanUpdate
         """
@@ -58,7 +57,8 @@ class ScannerContainer:
             genre_ids = []
         else:
             return
-        artist_ids = App().artists.get_ids(genre_ids)
+        storage_type = get_default_storage_type()
+        artist_ids = App().artists.get_ids(genre_ids, storage_type)
         # We only test add, remove and absent is safe
         if artist_id not in artist_ids and scan_update == ScanUpdate.ADDED:
             return
@@ -67,5 +67,18 @@ class ScannerContainer:
         genre_ids = []
         if scan_update == ScanUpdate.ADDED:
             selection_list.add_value((artist_id, artist_name, sortname))
-        elif not App().albums.get_ids([artist_id], genre_ids):
+        elif not App().albums.get_ids(
+                genre_ids, [artist_id], storage_type, True):
             selection_list.remove_value(artist_id)
+
+    def __on_collection_updated(self, scanner, item, scan_update):
+        """
+            Update lists based on collection changes
+            @param scanner as CollectionScanner
+            @param item as CollectionItem
+            @param scan_update as ScanUpdate
+        """
+        for genre_id in item.genre_ids:
+            self.__handle_genre_update(genre_id, scan_update)
+        for artist_id in item.artist_ids:
+            self.__handle_artist_update(artist_id, scan_update)
