@@ -108,7 +108,7 @@ class ViewType:
     PLAYLISTS = 1 << 5
     ALBUM = 1 << 6
     SMALL = 1 << 7
-    ADAPTIVE = 1 << 8
+    # ADAPTIVE = 1 << 8
     SCROLLED = 1 << 9
     OVERLAY = 1 << 10
     FULLSCREEN = 1 << 11
@@ -179,7 +179,7 @@ class ScanUpdate:
 class SelectionListMask:
     NONE = 1 << 0
     SIDEBAR = 1 << 1
-    VIEW = 1 << 2
+    FASTSCROLL = 1 << 2
     ARTISTS = 1 << 3
     GENRES = 1 << 4
     PLAYLISTS = 1 << 5
@@ -207,16 +207,6 @@ class ReplayGain:
     ALBUM = 1
 
 
-class AdaptiveSize:
-    NONE = 1 << 0
-    PHONE = 1 << 1
-    SMALL = 1 << 2
-    MEDIUM = 1 << 3
-    NORMAL = 1 << 4
-    BIG = 1 << 5
-    LARGE = 1 << 6
-
-
 class Size:
     MINI = 250
     PHONE = 360  # Librem Phone
@@ -227,12 +217,12 @@ class Size:
 
 
 class OrderBy:
-    ARTIST = 0
-    NAME = 1
-    YEAR_DESC = 2
-    POPULARITY = 3
-    YEAR_ASC = 4  # Not available for user
-    GENRE = 5
+    ARTIST_YEAR = 0
+    ARTIST_TITLE = 1
+    TITLE = 2
+    YEAR_DESC = 3
+    POPULARITY = 4
+    YEAR_ASC = 5
 
 
 # Order is important
@@ -255,16 +245,9 @@ class Type:
     GENRES_LIST = -14
     YEARS = -15
     PLAYLISTS = -16
-    RADIOS = -17
     INFO = -18
     SMART = -19
     EQUALIZER = -20
-    SETTINGS = -21
-    SETTINGS_APPEARANCE = -22
-    SETTINGS_BEHAVIOUR = -23
-    SETTINGS_COLLECTIONS = -24
-    SETTINGS_WEB = -25
-    SETTINGS_DEVICES = -26
     DEVICE_ALBUMS = -27
     DEVICE_PLAYLISTS = -28
     ALBUM = -29
