@@ -11,12 +11,18 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from gi.repository import Gio, GLib
+from gi.repository.Gio import FILE_ATTRIBUTE_STANDARD_TYPE,\
+    FILE_ATTRIBUTE_STANDARD_FAST_CONTENT_TYPE
 
 from lollypop.define import App, ScanType
-from lollypop.utils import is_audio
+from lollypop.utils_file import is_audio
 from lollypop.logger import Logger
 
 
+SCAN_QUERY_INFO = "{},{}".format(FILE_ATTRIBUTE_STANDARD_TYPE,
+                                 FILE_ATTRIBUTE_STANDARD_FAST_CONTENT_TYPE)
+
+
 class Inotify:
     """
         Inotify support
@@ -82,12 +88,14 @@ class Inotify:
         if changed_uri in self.__monitors.keys() and\
                 self.__monitors[changed_uri] == monitor:
             return
-        # Ignore non audio/dir
-        if changed_file.query_exists() and\
-                not is_audio(changed_file) and\
-                changed_file.query_file_type(Gio.FileQueryInfoFlags.NONE,
-                                             None) != Gio.FileType.DIRECTORY:
-            return
+
+        if changed_file.query_exists():
+            # Ignore non audio
+            info = changed_file.query_info(SCAN_QUERY_INFO,
+                                           Gio.FileQueryInfoFlags.NONE)
+            if info.get_file_type() != Gio.FileType.DIRECTORY and\
+                    is_audio(info):
+                return
 
         # Stop collection scanner and wait
         if App().scanner.is_locked():
