@@ -21,7 +21,6 @@ from random import randint
 from lollypop.logger import Logger
 from lollypop.define import App, ArtSize, Repeat, Notifications
 from lollypop.objects_track import Track
-from lollypop.objects_radio import Radio
 
 
 class Server:
@@ -377,7 +376,9 @@ class MPRIS(Server):
             return "Stopped"
 
     def __update_metadata(self):
-        if self.__get_status() == "Stopped":
+        self.__metadata = {}
+        if App().player.current_track.id is None or\
+                self.__get_status() == "Stopped":
             self.__metadata = {"mpris:trackid": GLib.Variant(
                 "o",
                 "/org/mpris/MediaPlayer2/TrackList/NoTrack")}
@@ -403,23 +404,17 @@ class MPRIS(Server):
                 App().player.current_track.album_artists)
             self.__metadata["mpris:length"] = GLib.Variant(
                 "x",
-                App().player.current_track.duration * 1000 * 1000)
+                App().player.current_track.duration * 1000)
             self.__metadata["xesam:genre"] = GLib.Variant(
                 "as",
                 App().player.current_track.genres)
             self.__metadata["xesam:url"] = GLib.Variant(
                 "s",
                 App().player.current_track.uri)
-            self.__rating = App().player.current_track.get_rate()
             self.__metadata["xesam:userRating"] = GLib.Variant(
                 "d",
-                self.__rating / 5)
-            if isinstance(App().player.current_track, Radio):
-                cover_path = App().art.get_radio_cache_path(
-                    App().player.current_track.name,
-                    ArtSize.MPRIS, ArtSize.MPRIS)
-            else:
-                cover_path = App().art.get_album_cache_path(
+                App().player.current_track.rate / 5)
+            cover_path = App().art.get_album_cache_path(
                     App().player.current_track.album,
                     ArtSize.MPRIS, ArtSize.MPRIS)
             if cover_path is not None:
