@@ -17,11 +17,10 @@ from gettext import gettext as _
 
 from lollypop.tagreader import TagReader, Discoverer
 from lollypop.player_plugins import PluginsPlayer
-from lollypop.define import GstPlayFlags, App
+from lollypop.define import GstPlayFlags, App, StorageType
 from lollypop.codecs import Codecs
 from lollypop.logger import Logger
 from lollypop.objects_track import Track
-from lollypop.objects_radio import Radio
 from lollypop.utils import emit_signal, get_network_available
 
 
@@ -34,10 +33,12 @@ class BinPlayer:
         """
             Init playbin
         """
+        # In the case of gapless playback, both 'about-to-finish'
+        # and 'eos' can occur during the same stream.
+        self.__track_in_pipe = False
         self.__cancellable = Gio.Cancellable()
         self.__codecs = Codecs()
         self._current_track = Track()
-        self._current_playback_track = Track()
         self._next_track = Track()
         self._prev_track = Track()
         self._playbin = self._playbin1 = Gst.ElementFactory.make(
@@ -88,12 +89,8 @@ class BinPlayer:
         """
             Change player state to PAUSED
         """
-        if isinstance(App().player.current_track, Radio):
-            self._playbin.set_state(Gst.State.NULL)
-            emit_signal(self, "status-changed")
-        else:
-            self._playbin.set_state(Gst.State.PAUSED)
-            emit_signal(self, "status-changed")
+        self._playbin.set_state(Gst.State.PAUSED)
+        emit_signal(self, "status-changed")
 
     def stop(self):
         """
@@ -101,6 +98,7 @@ class BinPlayer:
             @param force as bool
         """
         self._current_track = Track()
+        self._current_track = Track()
         self._prev_track = Track()
         self._next_track = Track()
         emit_signal(self, "current-changed")
@@ -244,19 +242,17 @@ class BinPlayer:
             @param track as Track
             @return False if track not loaded
         """
+        self.__track_in_pipe = True
         Logger.debug("BinPlayer::_load_track(): %s" % track.uri)
         try:
-            self.__cancellable.cancel()
-            self.__cancellable = Gio.Cancellable()
-            if self._current_track.is_web:
-                emit_signal(self, "loading-changed", False, track)
+            emit_signal(self, "loading-changed", False, self._current_track)
             self._current_track = track
-            # We check track is URI track, if yes, do a load from Web
-            # Will not work if we add another music provider one day
+            # If track_uri is different, preload has happened
+            # See Player.set_next()
             track_uri = App().tracks.get_uri(track.id)
             if track.is_web and track.uri == track_uri:
                 emit_signal(self, "loading-changed", True, track)
-                App().task_helper.run(self._load_from_web, track)
+                self.__load_from_web(track)
                 return False
             else:
                 self._playbin.set_property("uri", track.uri)
@@ -265,52 +261,6 @@ class BinPlayer:
             return False
         return True
 
-    def _load_from_web(self, track, play=True):
-        """
-            Load track from web
-            @param track as Track
-            @param play as bool
-        """
-        def play_uri(uri):
-            track.set_uri(uri)
-            if play:
-                self.load(track)
-                App().task_helper.run(self.__update_current_duration,
-                                      track, uri)
-
-        if get_network_available():
-            from lollypop.helper_web import WebHelper
-            helper = WebHelper()
-            helper.set_uri(track, self.__cancellable)
-            uri = helper.get_track_content(track)
-            if uri is not None:
-                GLib.idle_add(play_uri, uri)
-            elif play:
-                GLib.idle_add(
-                    App().notify.send,
-                    "Lollypop",
-                    _("Can't find this track on YouTube"))
-                self.next()
-        elif play:
-            self.skip_album()
-
-    def _scrobble(self, finished, finished_start_time):
-        """
-            Scrobble on lastfm
-            @param finished as Track
-            @param finished_start_time as int
-        """
-        played = time() - finished_start_time
-        # Last.fm policy, force it for ListenBrainz too
-        if finished.duration < 30000:
-            return
-        # We can listen if the track has been played
-        # for at least half its duration, or for 4 minutes
-        if played >= finished.duration / 2000 or played >= 240:
-            for scrobbler in App().scrobblers:
-                if scrobbler.available:
-                    scrobbler.listen(finished, int(finished_start_time))
-
     def _on_stream_start(self, bus, message):
         """
             On stream start
@@ -318,17 +268,14 @@ class BinPlayer:
             @param bus as Gst.Bus
             @param message as Gst.Message
         """
-        if self._current_track.is_web:
-            emit_signal(self, "loading-changed", False,
-                        self._current_track.album)
+        self.__track_in_pipe = False
+        emit_signal(self, "loading-changed", False, self._current_track)
         self._start_time = time()
         Logger.debug("Player::_on_stream_start(): %s" %
                      self._current_track.uri)
         emit_signal(self, "current-changed")
-        for scrobbler in App().scrobblers:
-            if scrobbler.available:
-                scrobbler.playing_now(self._current_track)
-        App().tracks.set_listened_at(self._current_track.id, int(time()))
+        for scrobbler in App().ws_director.scrobblers:
+            scrobbler.playing_now(self._current_track)
 
     def _on_bus_message_tag(self, bus, message):
         """
@@ -336,15 +283,15 @@ class BinPlayer:
             @param bus as Gst.Bus
             @param message as Gst.Message
         """
-        if isinstance(self._current_track, Track):
+        if self._current_track.storage_type != StorageType.EXTERNAL:
             return
         Logger.debug("Player::__on_bus_message_tag(): %s" %
                      self._current_track.uri)
         reader = TagReader()
         tags = message.parse_tag()
         title = reader.get_title(tags, "")
-        if len(title) > 1 and self._current_track.artists != [title]:
-            self._current_track.artists = [title]
+        if len(title) > 1 and self._current_track.title != title:
+            self._current_track.set_name(title)
             emit_signal(self, "current-changed")
 
     def _on_bus_element(self, bus, message):
@@ -364,7 +311,7 @@ class BinPlayer:
         """
         if self._current_track.is_web:
             emit_signal(self, "loading-changed", False,
-                        self._current_track.album)
+                        self._current_track)
         Logger.info("Player::_on_bus_error(): %s" % message.parse_error()[1])
         if self.current_track.id is not None and self.current_track.id >= 0:
             if self.__codecs.is_missing_codec(message):
@@ -378,18 +325,14 @@ class BinPlayer:
 
     def _on_bus_eos(self, bus, message):
         """
-            Continue playback if possible and wanted
-            go next otherwise
+            If we are current bus, try to restart playback
+            Else stop playback
         """
-        # Don't do anything if crossfade on, track already changed
-        if self.crossfading:
+        if self.__track_in_pipe:
             return
-        if isinstance(App().player.current_track, Radio):
-            return
-        if self.is_playing and self._playbin.get_bus() == bus:
+        if self._playbin.get_bus() == bus:
             if self._next_track.id is None:
-                # We are in gstreamer thread
-                GLib.idle_add(self.stop)
+                self.stop()
             else:
                 self._load_track(self._next_track)
                 self.next()
@@ -401,36 +344,34 @@ class BinPlayer:
         """
         try:
             Logger.debug("Player::__on_stream_about_to_finish(): %s" % playbin)
-            # Don't do anything if crossfade on, track already changed
-            if self.crossfading:
-                return
-            if isinstance(App().player.current_track, Radio):
-                return
-            self._scrobble(self._current_track, self._start_time)
-            # Increment popularity
-            if self._current_track.id is not None and\
-                    self._current_track.id >= 0:
-                App().tracks.set_more_popular(self._current_track.id)
-                # In party mode, linear popularity
-                if self.is_party:
-                    pop_to_add = 1
-                # In normal mode, based on tracks count
-                else:
-                    count = self._current_track.album.tracks_count
-                    pop_to_add = int(App().albums.max_count / count)
-                App().albums.set_more_popular(self._current_track.album_id,
-                                              pop_to_add)
-            if self._next_track.id is None:
-                # We are in gstreamer thread
-                GLib.idle_add(self.stop)
-            else:
-                self._load_track(self._next_track)
+            # Don't do anything if crossfade on, track already scrobbled
+            # See TransitionsPlayer
+            if not self.crossfading:
+                self._on_track_finished(App().player.current_track)
+                if self._next_track.id is not None:
+                    self._load_track(self._next_track)
         except Exception as e:
             Logger.error("BinPlayer::_on_stream_about_to_finish(): %s", e)
 
 #######################
 # PRIVATE             #
 #######################
+    def __load_from_web(self, track):
+        """
+            Load track from web
+            @param track as Track
+        """
+        if get_network_available():
+            self.__cancellable.cancel()
+            self.__cancellable = Gio.Cancellable.new()
+            from lollypop.helper_web import WebHelper
+            helper = WebHelper(track, self.__cancellable)
+            helper.connect("loaded", self.__on_web_helper_loaded,
+                           track, self.__cancellable)
+            helper.load()
+        else:
+            self.skip_album()
+
     def __get_bin_position(self, playbin):
         """
             Get position for playbin
@@ -439,15 +380,14 @@ class BinPlayer:
         """
         return playbin.query_position(Gst.Format.TIME)[1] / 1000000
 
-    def __update_current_duration(self, track, uri):
+    def __update_current_duration(self, track):
         """
             Update current track duration
             @param track as Track
-            @param uri as str
         """
         try:
             discoverer = Discoverer()
-            duration = discoverer.get_info(uri).get_duration() / 1000000
+            duration = discoverer.get_info(track.uri).get_duration() / 1000000
             if duration != track.duration and duration > 0:
                 App().tracks.set_duration(track.id, int(duration))
                 track.reset("duration")
@@ -463,3 +403,24 @@ class BinPlayer:
         """
         App().settings.set_value("volume-rate", GLib.Variant("d", self.volume))
         emit_signal(self, "volume-changed")
+
+    def __on_web_helper_loaded(self, helper, uri, track, cancellable):
+        """
+            Play track URI
+            @param helper as WebHelper
+            @param uri as str
+            @param track as Track
+            @param cancellable as Gio.Cancellable
+        """
+        if cancellable.is_cancelled():
+            return
+        if uri:
+            track.set_uri(uri)
+            self.load(track)
+            App().task_helper.run(self.__update_current_duration, track)
+        else:
+            GLib.idle_add(
+                App().notify.send,
+                "Lollypop",
+                _("Can't find this track on YouTube"))
+            self.next()
