@@ -22,6 +22,10 @@ class PluginsPlayer:
         Replay gain player
     """
 
+    __EQUALIZER = [55, 77, 110, 156, 220, 311, 440, 622,
+                   880, 1200, 1800, 2500, 3500, 5000, 7000,
+                   10000, 14000, 20000]
+
     def __init__(self, playbin):
         """
             Init playbin
@@ -34,54 +38,65 @@ class PluginsPlayer:
     def build_audiofilter(self):
         """
             Build audio filter
+            audioconvert ! (rgvolume ! rglimiter ! audioconvert) !
+            (equalizer) ! volume ! audioconvert ! audiosink
         """
         try:
-            self.__playbin.set_property("audio-filter", None)
-            audiofilter = Gst.ElementFactory.make("bin", None)
-            # Internal volume manager
-            self.volume = Gst.ElementFactory.make("volume", None)
-            self.volume.props.volume = 0.0
-            audiofilter.add(self.volume)
-            # Equalizer
-            self.__equalizer = None
-            if App().settings.get_value("equalizer-enabled"):
-                self.__equalizer = Gst.ElementFactory.make("equalizer-10bands",
-                                                           None)
-                audiofilter.add(self.__equalizer)
-                self.volume.link(self.__equalizer)
+            audiobin = Gst.ElementFactory.make("bin", None)
+            audioconvert_in = Gst.ElementFactory.make("audioconvert", None)
+            audiobin.add(audioconvert_in)
             # Replay gain
-            replay_gain = App().settings.get_enum("replay-gain")
-            if replay_gain != ReplayGain.NONE:
+            replay_gain = App().settings.get_enum(
+                "replay-gain") != ReplayGain.NONE
+            if replay_gain:
                 rgvolume = Gst.ElementFactory.make("rgvolume", None)
+                rglimiter = Gst.ElementFactory.make("rglimiter", None)
+                audioconvert_rg = Gst.ElementFactory.make("audioconvert", None)
+                audiobin.add(rgvolume)
+                audiobin.add(rglimiter)
+                audiobin.add(audioconvert_rg)
+                audioconvert_in.link(rgvolume)
+                rgvolume.link(rglimiter)
+                rglimiter.link(audioconvert_rg)
                 if replay_gain == ReplayGain.ALBUM:
                     rgvolume.props.album_mode = 1
                 else:
                     rgvolume.props.album_mode = 0
                 rgvolume.props.pre_amp = App().settings.get_value(
                     "replay-gain-db").get_double()
-                audiofilter.add(rgvolume)
-                rglimiter = Gst.ElementFactory.make("rglimiter", None)
                 rglimiter.props.enabled = App().settings.get_value(
                     "replay-gain-limiter")
-                audiofilter.add(rglimiter)
-                rgvolume.link(rglimiter)
-                pad_src = rglimiter.get_static_pad("src")
-                if self.__equalizer is not None:
-                    self.volume.link(self.__equalizer)
-                    self.__equalizer.link(rgvolume)
+
+            # Equalizer
+            self.__equalizer = None
+            if App().settings.get_value("equalizer-enabled"):
+                self.__equalizer = Gst.ElementFactory.make("equalizer-nbands",
+                                                           None)
+                self.__equalizer.set_property("num-bands", 18)
+                audiobin.add(self.__equalizer)
+                if replay_gain:
+                    audioconvert_rg.link(self.__equalizer)
                 else:
-                    self.volume.link(rgvolume)
-            elif self.__equalizer is not None:
-                pad_src = self.__equalizer.get_static_pad("src")
-                self.volume.link(self.__equalizer)
+                    audioconvert_in.link(self.__equalizer)
+
+            # Internal volume manager
+            self.volume = Gst.ElementFactory.make("volume", None)
+            self.volume.props.volume = 1.0
+            audiobin.add(self.volume)
+            if self.__equalizer is not None:
+                self.__equalizer.link(self.volume)
+            elif replay_gain:
+                audioconvert_rg.link(self.volume)
             else:
-                pad_src = self.volume.get_static_pad("src")
-            ghost_src = Gst.GhostPad.new("src", pad_src)
-            audiofilter.add_pad(ghost_src)
-            pad_sink = self.volume.get_static_pad("sink")
-            ghost_sink = Gst.GhostPad.new("sink", pad_sink)
-            audiofilter.add_pad(ghost_sink)
-            self.__playbin.set_property("audio-filter", audiofilter)
+                audioconvert_in.link(self.volume)
+
+            audiosink = Gst.ElementFactory.make("autoaudiosink", None)
+            audiobin.add(audiosink)
+            self.volume.link(audiosink)
+            audiobin.add_pad(Gst.GhostPad.new(
+                "sink",
+                audioconvert_in.get_static_pad("sink")))
+            self.__playbin.set_property("audio-sink", audiobin)
             if self.__equalizer is not None:
                 self.update_equalizer()
         except Exception as e:
@@ -96,15 +111,17 @@ class PluginsPlayer:
             self.set_equalizer(i, value)
             i += 1
 
-    def set_equalizer(self, band, value):
+    def set_equalizer(self, index, value):
         """
-            Set 10bands equalizer
-            @param band as int
+            Set band value
+            @param index as int
             @param value as int
         """
         try:
             if self.__equalizer is not None:
-                self.__equalizer.set_property("band%s" % band, value)
+                band = self.__equalizer.get_child_by_index(index)
+                band.set_property("freq", self.__EQUALIZER[index])
+                band.set_property("gain", value)
         except Exception as e:
             Logger.error("PluginsPlayer::set_equalizer():", e)
 
