@@ -244,6 +244,9 @@ class SelectionListRow(Gtk.ListBoxRow):
         emit_signal(self, "populated")
 
 
+# TODO: There is no reason today to share a common class for sidebar and lists
+# Code cleanup needed, will simplify things!
+# Historical because previously, sidebar was a sidebar + a list
 class SelectionList(LazyLoadingView, GesturesHelper):
     """
         A list for artists/genres
@@ -269,23 +272,23 @@ class SelectionList(LazyLoadingView, GesturesHelper):
         GesturesHelper.__init__(self, self._box)
         self.__scrolled = Gtk.ScrolledWindow()
         self.__scrolled.show()
-        self.__scrolled.set_property("expand", True)
+        self.__scrolled.set_policy(Gtk.PolicyType.NEVER,
+                                   Gtk.PolicyType.AUTOMATIC)
         self.__viewport = Gtk.Viewport()
         self.__scrolled.add(self.__viewport)
         self.__viewport.show()
         self.__viewport.add(self._box)
         self.connect("initialized", self.__on_initialized)
-        if self.__base_mask & SelectionListMask.VIEW:
+        self.get_style_context().add_class("sidebar")
+        self.__scrolled.set_vexpand(True)
+        if base_mask & SelectionListMask.FASTSCROLL:
             self.__overlay = Gtk.Overlay.new()
-            self.__overlay.set_hexpand(True)
-            self.__overlay.set_vexpand(True)
             self.__overlay.show()
             self.__overlay.add(self.__scrolled)
             self.__fastscroll = FastScroll(self._box,
                                            self.__scrolled)
             self.__overlay.add_overlay(self.__fastscroll)
             self.add(self.__overlay)
-            self.__base_mask |= SelectionListMask.LABEL
             App().settings.connect("changed::artist-artwork",
                                    self.__on_artist_artwork_changed)
             App().art.connect("artist-artwork-changed",
@@ -294,10 +297,7 @@ class SelectionList(LazyLoadingView, GesturesHelper):
             self.__overlay = None
             App().settings.connect("changed::show-sidebar-labels",
                                    self.__on_show_sidebar_labels_changed)
-            self.__scrolled.set_policy(Gtk.PolicyType.NEVER,
-                                       Gtk.PolicyType.AUTOMATIC)
             self.add(self.__scrolled)
-            self.get_style_context().add_class("sidebar")
             self.__menu_button = Gtk.Button.new_from_icon_name(
                 "view-more-horizontal-symbolic", Gtk.IconSize.BUTTON)
             self.__menu_button.set_property("halign", Gtk.Align.CENTER)
@@ -306,6 +306,14 @@ class SelectionList(LazyLoadingView, GesturesHelper):
                                        lambda x: self.__popup_menu(None, x))
             self.__menu_button.show()
             self.add(self.__menu_button)
+        if base_mask & SelectionListMask.SIDEBAR:
+            App().window.container.widget.connect("notify::folded",
+                                                  self.__on_container_folded)
+            self.__on_container_folded(None, App().window.folded)
+        else:
+            self.__base_mask |= SelectionListMask.LABEL
+            self.__base_mask |= SelectionListMask.ELLIPSIZE
+            self.__set_rows_mask(self.__base_mask | self.__mask)
 
     def set_mask(self, mask):
         """
@@ -347,11 +355,13 @@ class SelectionList(LazyLoadingView, GesturesHelper):
             @param value as (int, str, optional str)
         """
         self._box.set_sort_func(self.__sort_func)
-        child = self._get_child(value)
-        child.populate()
-        if self.mask & SelectionListMask.ARTISTS:
-            self.__fastscroll.clear()
-            self.__fastscroll.populate()
+        ids = [row.id for row in self._box.get_children()]
+        if value[0] not in ids:
+            child = self._get_child(value)
+            child.populate()
+            if self.mask & SelectionListMask.ARTISTS:
+                self.__fastscroll.clear()
+                self.__fastscroll.populate()
 
     def update_value(self, object_id, name):
         """
@@ -366,7 +376,7 @@ class SelectionList(LazyLoadingView, GesturesHelper):
                 found = True
                 break
         if not found:
-            if self.__base_mask & SelectionListMask.VIEW:
+            if self.__base_mask & SelectionListMask.FASTSCROLL:
                 self.__fastscroll.clear()
             self.add_value((object_id, name, name))
 
@@ -375,7 +385,7 @@ class SelectionList(LazyLoadingView, GesturesHelper):
             Update view with values
             @param [(int, str, optional str)]
         """
-        if self.mask & SelectionListMask.VIEW:
+        if self.mask & SelectionListMask.FASTSCROLL:
             self.__fastscroll.clear()
         # Remove not found items
         value_ids = set([v[0] for v in values])
@@ -418,7 +428,7 @@ class SelectionList(LazyLoadingView, GesturesHelper):
         self.stop()
         for child in self._box.get_children():
             child.destroy()
-        if self.__base_mask & SelectionListMask.VIEW:
+        if self.__base_mask & SelectionListMask.FASTSCROLL:
             self.__fastscroll.clear()
             self.__fastscroll.clear_chars()
 
@@ -515,6 +525,14 @@ class SelectionList(LazyLoadingView, GesturesHelper):
         """
         return [row.id for row in self._box.get_selected_rows()]
 
+    @property
+    def scrolled(self):
+        """
+            Get scrolled window
+            @return Gtk.ScrolledWindow
+        """
+        return self.__scrolled
+
     @property
     def selected_id(self):
         """
@@ -552,30 +570,6 @@ class SelectionList(LazyLoadingView, GesturesHelper):
         if coordinates:
             self.__scrolled.get_vadjustment().set_value(coordinates[1])
 
-    def _on_adaptive_changed(self, window, status):
-        """
-            Update internals
-            @param window as Window
-            @param status as bool
-        """
-        self.__base_mask &= ~(SelectionListMask.LABEL |
-                              SelectionListMask.ELLIPSIZE)
-        if status or self.__base_mask & SelectionListMask.VIEW:
-            self.__base_mask |= (SelectionListMask.LABEL |
-                                 SelectionListMask.ELLIPSIZE)
-        elif App().settings.get_value("show-sidebar-labels"):
-            self.__base_mask |= SelectionListMask.LABEL
-        self.__set_rows_mask(self.__base_mask | self.__mask)
-
-    def _on_map(self, widget):
-        """
-            Unselect all if adaptive
-            @param widget as Gtk.Widget
-        """
-        LazyLoadingView._on_map(self, widget)
-        if App().window.is_adaptive:
-            self._box.unselect_all()
-
     def _on_primary_long_press_gesture(self, x, y):
         """
             Show row menu
@@ -619,10 +613,6 @@ class SelectionList(LazyLoadingView, GesturesHelper):
         """
         for row in self._box.get_children():
             row.set_mask(mask)
-        if mask & SelectionListMask.ELLIPSIZE:
-            self.__scrolled.set_hexpand(True)
-        else:
-            self.__scrolled.set_hexpand(False)
 
     def __sort_func(self, row_a, row_b):
         """
@@ -669,11 +659,11 @@ class SelectionList(LazyLoadingView, GesturesHelper):
                 from lollypop.menu_selectionlist import SelectionListMenu
                 menu = SelectionListMenu(self,
                                          self.mask,
-                                         App().window.is_adaptive)
+                                         App().window.folded)
             elif not App().settings.get_value("save-state"):
                 from lollypop.menu_selectionlist import SelectionListRowMenu
                 menu = SelectionListRowMenu(row_id,
-                                            App().window.is_adaptive)
+                                            App().window.folded)
             if menu is not None:
                 from lollypop.widgets_menu import MenuBuilder
                 menu_widget = MenuBuilder(menu)
@@ -702,7 +692,7 @@ class SelectionList(LazyLoadingView, GesturesHelper):
             @param settings as Gio.Settings
             @param value as str
         """
-        self._on_adaptive_changed(App().window, App().window.is_adaptive)
+        self.__on_container_folded(None, App().window.folded)
 
     def __on_initialized(self, selectionlist):
         """
@@ -715,3 +705,16 @@ class SelectionList(LazyLoadingView, GesturesHelper):
         for row in self._box.get_selected_rows():
             GLib.idle_add(self._scroll_to_child, row)
             break
+
+    def __on_container_folded(self, leaflet, folded):
+        """
+            Update internals
+            @param leaflet as Handy.Leaflet
+            @param folded as Gparam
+        """
+        folded = App().window.folded
+        self.__base_mask &= ~SelectionListMask.LABEL
+        self.__scrolled.set_hexpand(folded)
+        if folded or App().settings.get_value("show-sidebar-labels"):
+            self.__base_mask |= SelectionListMask.LABEL
+        self.__set_rows_mask(self.__base_mask | self.__mask)
