@@ -17,7 +17,10 @@ from gettext import gettext as _
 
 from lollypop.define import App
 from lollypop.logger import Logger
+from lollypop.utils_file import decodeUnicode, splitUnicode
 from lollypop.utils import format_artist_name, get_iso_date_from_string
+from lollypop.tag_frame_text import FrameTextTag
+from lollypop.tag_frame_lang import FrameLangTag
 
 
 class Discoverer:
@@ -106,6 +109,22 @@ class TagReader:
                 composers.append(read)
         return "; ".join(composers)
 
+    def get_conductors(self, tags):
+        """
+            Return conductors for tags
+            @param tags as Gst.TagList
+            @return string like "conductor1;conductor2;..."
+        """
+        if tags is None:
+            return _("Unknown")
+        conductors = []
+        for i in range(tags.get_tag_size("conductor")):
+            (exists, read) = tags.get_string_index("conductor", i)
+            # We need to check tag is not just spaces
+            if exists and read.strip(" "):
+                conductors.append(read)
+        return "; ".join(conductors)
+
     def get_mb_id(self, tags, name):
         """
             Get MusicBrainz ID
@@ -311,6 +330,40 @@ class TagReader:
             discnumber = 0
         return discnumber
 
+    def get_compilation(self, tags):
+        """
+            Return True if album is a compilation
+            @param tags as Gst.TagList
+            @return bool
+        """
+        if tags is None:
+            return False
+        size = tags.get_tag_size("private-id3v2-frame")
+        for i in range(0, size):
+            (exists, sample) = tags.get_sample_index(
+                "private-id3v2-frame",
+                i)
+            if not exists:
+                continue
+            (exists, m) = sample.get_buffer().map(Gst.MapFlags.READ)
+            if not exists:
+                continue
+            frame = FrameTextTag(m.data)
+            if frame.key == "TCMP":
+                string = frame.string
+                if not string:
+                    Logger.debug(tags.to_string())
+                return string and string[-1] == "1"
+        size = tags.get_tag_size("extended-comment")
+        for i in range(0, size):
+            (exists, sample) = tags.get_string_index(
+                "extended-comment",
+                i)
+            if not exists or not sample.startswith("COMPILATION="):
+                continue
+            return sample[12]
+        return False
+
     def get_tracknumber(self, tags, filename):
         """
             Return track number for tags
@@ -389,10 +442,11 @@ class TagReader:
                     (exists, m) = sample.get_buffer().map(Gst.MapFlags.READ)
                     if not exists:
                         continue
-                    string = m.data.decode("utf-8")
-                    if string.startswith("TDOR"):
-                        split = string.split("\x00")
-                        date = get_iso_date_from_string(split[-1])
+                    frame = FrameTextTag(m.data)
+                    if frame.key == "TDOR":
+                        if not frame.string:
+                            Logger.debug(tags.to_string())
+                        date = get_iso_date_from_string(frame.string)
                         datetime = GLib.DateTime.new_from_iso8601(date, None)
                         return (datetime.get_year(), datetime.to_unix())
             except:
@@ -520,14 +574,10 @@ class TagReader:
             @return lyrics as str
         """
         def decode_lyrics(bytes):
-            from lollypop.utils_file import decodeUnicode, splitUnicode
             try:
-                prefix = bytes[0:4]
-                if prefix in [b"USLT"]:
-                    frame = bytes[10:]
-                    encoding = frame[0:1]
-                    (d, t) = splitUnicode(frame[4:], encoding)
-                    return decodeUnicode(t, encoding)
+                frame = FrameLangTag(bytes)
+                if frame.key == "USLT":
+                    return frame.string
             except Exception as e:
                 Logger.warning("TagReader::get_lyrics(): %s", e)
             return None
@@ -591,7 +641,6 @@ class TagReader:
         """
         def decode_lyrics(bytes_list, encoding):
             lyrics = []
-            from lollypop.utils_file import decodeUnicode, splitUnicode
             try:
                 for frame in bytes_list:
                     (l, t) = splitUnicode(frame, encoding)
@@ -725,6 +774,15 @@ class TagReader:
             if parent is not None:
                 uri = parent.get_uri()
         album_id = App().albums.get_id(album_name, mb_album_id, artist_ids)
+        # Check storage type did not changed, remove album then
+        if album_id is not None:
+            current_storage_type = App().albums.get_storage_type(album_id)
+            if current_storage_type != storage_type:
+                App().tracks.remove_album(album_id)
+                App().tracks.clean(False)
+                App().albums.clean(False)
+                App().artists.clean(False)
+                album_id = None
         if album_id is None:
             added = True
             album_id = App().albums.add(album_name, mb_album_id, lp_album_id,
@@ -734,3 +792,7 @@ class TagReader:
         elif App().albums.get_uri(album_id) != uri:
             App().albums.set_uri(album_id, uri)
         return (added, album_id)
+
+#######################
+# PRIVATE             #
+#######################
