@@ -47,6 +47,7 @@ class ToolbarInfo(Gtk.Bin, ArtworkPlayerWidget, GesturesHelper):
         self.__artwork = ArtworkPlayerWidget(ArtBehaviour.CROP_SQUARE |
                                              ArtBehaviour.CACHE)
         self.__artwork.set_property("has-tooltip", True)
+        self.__artwork.set_margin_top(1)
         horizontal_box.pack_start(self.__artwork, False, False, 0)
         horizontal_box.pack_start(self.__label, False, False, 0)
         self.set_margin_start(MARGIN_SMALL)
@@ -97,7 +98,7 @@ class ToolbarInfo(Gtk.Bin, ArtworkPlayerWidget, GesturesHelper):
             @param x as int
             @param y as int
         """
-        if App().window.is_adaptive or not self.__artwork.get_visible():
+        if App().window.folded or not self.__artwork.get_visible():
             return
         if App().player.current_track.id is not None:
             self.__popup_menu()
@@ -109,7 +110,7 @@ class ToolbarInfo(Gtk.Bin, ArtworkPlayerWidget, GesturesHelper):
             @param y as int
             @param evnet as Gdk.Event
         """
-        if App().window.is_adaptive or not self.__artwork.get_visible():
+        if App().window.folded or not self.__artwork.get_visible():
             return
         if App().player.current_track.id is not None:
             from lollypop.pop_information import InformationPopover
@@ -133,7 +134,7 @@ class ToolbarInfo(Gtk.Bin, ArtworkPlayerWidget, GesturesHelper):
         """
             Show contextual menu
         """
-        if App().window.is_adaptive or not self.__artwork.get_visible():
+        if App().window.folded or not self.__artwork.get_visible():
             return
         track = App().player.current_track
         if track.id >= 0:
@@ -173,5 +174,5 @@ class ToolbarInfo(Gtk.Bin, ArtworkPlayerWidget, GesturesHelper):
             Calculate art size
             @param toolbar as ToolbarInfos
         """
-        art_size = self.get_allocated_height() - 2
+        art_size = self.get_allocated_height() - 1
         self.__artwork.set_art_size(art_size, art_size)
