@@ -318,20 +318,6 @@ def get_iso_date_from_string(string):
         return None
 
 
-def is_unity():
-    """
-        Return True if desktop is Unity
-    """
-    return GLib.getenv("XDG_CURRENT_DESKTOP") == "Unity"
-
-
-def is_gnome():
-    """
-        Return True if desktop is Gnome
-    """
-    return GLib.getenv("XDG_CURRENT_DESKTOP") in ["ubuntu:GNOME", "GNOME"]
-
-
 def format_artist_name(name):
     """
         Return formated artist name
@@ -442,8 +428,6 @@ def get_icon_name(object_id):
         icon = "system-users-symbolic"
     elif object_id == Type.RECENTS:
         icon = "document-open-recent-symbolic"
-    elif object_id == Type.RADIOS:
-        icon = "org.gnome.Lollypop-gradio-symbolic"
     elif object_id == Type.RANDOMS:
         icon = "media-playlist-shuffle-symbolic"
     elif object_id == Type.LOVED:
@@ -505,7 +489,7 @@ def popup_widget(widget, parent, x, y, state_widget):
     def on_unmap(popover, parent):
         parent.unset_state_flags(Gtk.StateFlags.VISITED)
 
-    if App().window.is_adaptive:
+    if App().window.folded:
         App().window.container.show_menu(widget)
         return None
     else:
