@@ -62,14 +62,15 @@ class FlowBoxView(LazyLoadingView, GesturesHelper):
             @param value as object
         """
         self._box.set_sort_func(self._sort_func)
-        LazyLoadingView.populate(self, [value])
+        self.add_value_unsorted(value)
 
     def add_value_unsorted(self, value):
         """
             Add value unsorted
             @param value as object
         """
-        LazyLoadingView.populate(self, [value])
+        child = self._get_child(value)
+        child.populate()
 
     def remove_value(self, value):
         """
@@ -125,28 +126,27 @@ class FlowBoxView(LazyLoadingView, GesturesHelper):
     def _sort_func(self, widget1, widget2):
         """
             Sort function
-            @param widget1 as RoundedArtistWidget
-            @param widget2 as RoundedArtistWidget
+            @param widget1 as Gtk.Widget
+            @param widget2 as Gtk.Widget
         """
         return strcoll(widget1.sortname, widget2.sortname)
 
     def _on_child_activated(self, flowbox, child):
         pass
 
-    def _on_adaptive_changed(self, window, status):
+    def _on_container_folded(self, leaflet, folded):
         """
-            Update artwork
-            @param window as Window
-            @param status as bool
+            Handle libhandy folded status
+            @param leaflet as Handy.Leaflet
+            @param folded as Gparam
         """
-        if LazyLoadingView._on_adaptive_changed(self, window, status):
-            self.pause()
-            children = self._box.get_children()
-            for child in children:
-                child.set_view_type(self.view_type)
-                child.disable_artwork()
-                self.queue_lazy_loading(child)
-            self.lazy_loading()
+        LazyLoadingView._on_container_folded(self, leaflet, folded)
+        self.pause()
+        children = self._box.get_children()
+        for child in children:
+            child.reset_artwork()
+            self.queue_lazy_loading(child)
+        self.lazy_loading()
 
     def _on_view_leave(self, event_controller):
         """
