@@ -10,13 +10,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import GLib
+from gi.repository import GLib, GObject
 
 from time import time
 
-from lollypop.define import ViewType, LoadingState
+from lollypop.define import LoadingState, App
 from lollypop.logger import Logger
 from lollypop.view import View
+from lollypop.utils import emit_signal
 
 
 class LazyLoadingView(View):
@@ -24,12 +25,20 @@ class LazyLoadingView(View):
         Lazy loading for view
     """
 
-    def __init__(self, view_type=ViewType.DEFAULT):
+    __gsignals__ = {
+        # View has been populated/depopulated, children are not populated
+        "initialized": (GObject.SignalFlags.RUN_FIRST, None, ()),
+        # All children are populated
+        "populated": (GObject.SignalFlags.RUN_FIRST, None, ()),
+    }
+
+    def __init__(self, storage_type, view_type):
         """
             Init lazy loading
+            @param storage_type as StorageType
             @param view_type as ViewType
         """
-        View.__init__(self, view_type)
+        View.__init__(self, storage_type, view_type)
         self.__loading_state = LoadingState.NONE
         self.__lazy_queue = []
         self.__priority_queue = []
@@ -79,12 +88,12 @@ class LazyLoadingView(View):
         """
         self.__lazy_queue.append(widget)
 
-    def set_external_scrolled(self, scrolled):
+    def set_scrolled(self, scrolled):
         """
-            Set an external scrolled window for loading
+            Add an external scrolled window
             @param scrolled as Gtk.ScrolledWindow
         """
-        self._scrolled = scrolled
+        View.set_scrolled(self, scrolled)
         scrolled.get_vadjustment().connect("value-changed",
                                            self._on_value_changed)
 
@@ -105,7 +114,7 @@ class LazyLoadingView(View):
             @param value as object
             @return object
         """
-        pass
+        return None
 
     def _on_map(self, widget):
         """
@@ -142,12 +151,6 @@ class LazyLoadingView(View):
             # RecursionError: maximum recursion depth exceeded
             GLib.idle_add(self.__lazy_loading)
 
-    def _on_initial_loading(self):
-        """
-            Initial loading is finished
-        """
-        pass
-
 #######################
 # PRIVATE             #
 #######################
@@ -167,6 +170,15 @@ class LazyLoadingView(View):
             widget.populate()
         else:
             self.__loading_state = LoadingState.FINISHED
+            emit_signal(self, "populated")
+            # Apply filtering
+            if App().window.container.type_ahead.get_reveal_child():
+                text = App().window.container.type_ahead.entry.get_text()
+                if text:
+                    self.search_for_child(text)
+                else:
+                    GLib.idle_add(
+                        App().window.container.type_ahead.entry.grab_focus)
             Logger.debug("LazyLoadingView::lazy_loading(): %s",
                          time() - self.__start_time)
 
@@ -183,7 +195,7 @@ class LazyLoadingView(View):
             GLib.idle_add(self.__add_values, values)
         elif self.__loading_state != LoadingState.RUNNING:
             self.__loading_state = LoadingState.RUNNING
-            self._on_initial_loading()
+            emit_signal(self, "initialized")
             self.__lazy_loading()
 
     def __is_visible(self, widget):
@@ -192,9 +204,9 @@ class LazyLoadingView(View):
             @param widget as Gtk.Widget
         """
         widget_alloc = widget.get_allocation()
-        scrolled_alloc = self._scrolled.get_allocation()
+        scrolled_alloc = self.scrolled.get_allocation()
         try:
-            (x, y) = widget.translate_coordinates(self._scrolled, 0, 0)
+            (x, y) = widget.translate_coordinates(self.scrolled, 0, 0)
             return (y > -widget_alloc.height or y >= 0) and\
                 y < scrolled_alloc.height
         except:
