@@ -16,9 +16,9 @@ from gettext import gettext as _
 
 from lollypop.define import App, StorageType
 from lollypop.define import ViewType, MARGIN
-from lollypop.search_local import LocalSearch
+from lollypop.search import Search
 from lollypop.view import View
-from lollypop.utils import get_network_available
+from lollypop.utils import sql_escape
 from lollypop.objects_album import Album
 from lollypop.objects_track import Track
 from lollypop.helper_signals import SignalsHelper, signals_map
@@ -33,21 +33,22 @@ class SearchGrid(Gtk.Grid):
         A grid for search
     """
 
-    def __init__(self):
+    def __init__(self, storage_type):
         """
             Init grid
+            @param storage_type as StorageType
         """
         Gtk.Grid.__init__(self)
         self.set_row_spacing(MARGIN)
         self.get_style_context().add_class("padding")
         self.set_orientation(Gtk.Orientation.VERTICAL)
         self.set_property("valign", Gtk.Align.START)
-        self.__artists_line_view = ArtistsSearchLineView()
-        self.__albums_line_view = AlbumsSearchLineView()
+        self.__artists_line_view = ArtistsSearchLineView(storage_type)
+        self.__albums_line_view = AlbumsSearchLineView(storage_type)
         self.__search_tracks_view = SearchTracksView()
-        self.add(self.__search_tracks_view)
-        self.add(self.__artists_line_view)
         self.add(self.__albums_line_view)
+        self.add(self.__artists_line_view)
+        self.add(self.__search_tracks_view)
 
     @property
     def search_tracks_view(self):
@@ -79,9 +80,10 @@ class SearchStack(Gtk.Stack):
         A stack for search
     """
 
-    def __init__(self):
+    def __init__(self, storage_type):
         """
             Init stack
+            @param storage_type as StorageType
         """
         Gtk.Stack.__init__(self)
         self.get_style_context().add_class("padding")
@@ -89,7 +91,7 @@ class SearchStack(Gtk.Stack):
         self.set_transition_type(Gtk.StackTransitionType.CROSSFADE)
         self.set_transition_duration(100)
         for i in range(0, 2):
-            grid = SearchGrid()
+            grid = SearchGrid(storage_type)
             grid.show()
             self.add(grid)
 
@@ -98,13 +100,14 @@ class SearchStack(Gtk.Stack):
             Set a new current child for search
             This is not visible child
         """
+        if self.__current_child is not None:
+            self.__current_child.search_tracks_view.clear()
+            self.__current_child.artists_line_view.clear()
+            self.__current_child.albums_line_view.clear()
         for child in self.get_children():
             if child != self.get_visible_child():
                 self.__current_child = child
                 break
-        self.__current_child.search_tracks_view.clear()
-        self.__current_child.artists_line_view.clear()
-        self.__current_child.albums_line_view.clear()
 
     @property
     def current_child(self):
@@ -112,6 +115,8 @@ class SearchStack(Gtk.Stack):
             Get non visible child
             @return SearchGrid
         """
+        if self.__current_child is None:
+            self.new_current_child()
         return self.__current_child
 
 
@@ -121,25 +126,34 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
     """
 
     @signals_map
-    def __init__(self, view_type, initial_search=""):
+    def __init__(self, initial_search, view_type):
         """
             Init Popover
-            @param view_type as ViewType
             @param initial_search as str
         """
-        View.__init__(self, view_type | ViewType.SCROLLED | ViewType.OVERLAY)
+        View.__init__(self,
+                      StorageType.COLLECTION |
+                      StorageType.SAVED |
+                      StorageType.SEARCH |
+                      StorageType.EPHEMERAL |
+                      StorageType.SPOTIFY_NEW_RELEASES |
+                      StorageType.SPOTIFY_SIMILARS,
+                      ViewType.SEARCH |
+                      ViewType.SCROLLED |
+                      ViewType.OVERLAY)
         Gtk.Bin.__init__(self)
         self.__timeout_id = None
         self.__current_search = ""
-        self.__local_search = LocalSearch()
-        self.__searches_count = 0
+        self.__search = Search()
+        self.__search.set_web_search(
+            App().settings.get_value("web-search").get_string())
         self.__cancellable = Gio.Cancellable()
         self._empty_message = _("Search for artists, albums and tracks")
         self._empty_icon_name = "edit-find-symbolic"
         self.__cancellable = Gio.Cancellable()
         self.__banner = SearchBannerWidget()
         self.__banner.show()
-        self.__stack = SearchStack()
+        self.__stack = SearchStack(self.storage_type)
         self.__stack.show()
         self.add_widget(self.__stack, self.__banner)
         self.__banner.entry.connect("changed", self._on_search_changed)
@@ -147,15 +161,12 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
                               _("Search for artists, albums and tracks"))
         self.set_search(initial_search)
         return [
-                (self.__local_search, "match-artist", "_on_match_artist"),
-                (self.__local_search, "match-album", "_on_match_album"),
-                (self.__local_search, "match-track", "_on_match_track"),
-                (self.__local_search, "search-finished",
-                 "_on_search_finished"),
-                (App().spotify, "match-album", "_on_match_album"),
-                (App().spotify, "match-track", "_on_match_track"),
-                (App().spotify, "search-finished",
-                 "_on_search_finished"),
+                (self.__search, "match-artist", "_on_match_artist"),
+                (self.__search, "match-album", "_on_match_album"),
+                (self.__search, "match-track", "_on_match_track"),
+                (self.__search, "finished", "_on_search_finished"),
+                (App().settings, "changed::web-search",
+                 "_on_web_search_changed")
         ]
 
     def populate(self):
@@ -168,27 +179,7 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
         if len(self.__current_search) > 1:
             self.__banner.spinner.start()
             current_search = self.__current_search.lower()
-            if App().settings.get_value("search-spotify") and\
-                    get_network_available("SPOTIFY") and\
-                    get_network_available("YOUTUBE"):
-                self.__searches_count += 1
-                # We want all items in DB
-                mask = StorageType.EPHEMERAL |\
-                    StorageType.SPOTIFY_NEW_RELEASES |\
-                    StorageType.SPOTIFY_SIMILARS |\
-                    StorageType.COLLECTION |\
-                    StorageType.SAVED |\
-                    StorageType.SEARCH
-                App().task_helper.run(App().spotify.search,
-                                      current_search,
-                                      self.__cancellable)
-            else:
-                # Only local items
-                mask = StorageType.COLLECTION |\
-                    StorageType.SAVED |\
-                    StorageType.SEARCH
-            self.__searches_count += 1
-            self.__local_search.get(current_search, mask, self.__cancellable)
+            self.__search.get(current_search, self.__cancellable)
         else:
             self.show_placeholder(True,
                                   _("Search for artists, albums and tracks"))
@@ -222,7 +213,8 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
             @return {}
         """
         search = self.__banner.entry.get_text().strip()
-        return {"view_type": self.view_type, "initial_search": search}
+        return {"initial_search": search,
+                "view_type": self.view_type}
 
 #######################
 # PROTECTED           #
@@ -235,7 +227,7 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
         View._on_map(self, widget)
         App().enable_special_shortcuts(False)
 
-    def __on_unmap(self, widget):
+    def _on_unmap(self, widget):
         """
             Cancel current loading and enable shortcuts
             @param widget as Gtk.Widget
@@ -243,13 +235,12 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
         View._on_unmap(self, widget)
         App().enable_special_shortcuts(True)
         self.cancel()
-        self.__view.stop()
         self.__banner.spinner.stop()
 
-    def _on_match_artist(self, local_search, artist_id, storage_type):
+    def _on_match_artist(self, search, artist_id, storage_type):
         """
             Add a new artist to view
-            @param local_search as LocalSearch
+            @param search as *Search
             @param artist_id as int
             @param storage_type as StorageType
         """
@@ -258,23 +249,33 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
             self.__stack.current_child.artists_line_view.add_value(artist_id)
             self.show_placeholder(False)
 
-    def _on_match_album(self, local_search, album_id, storage_type):
+    def _on_match_album(self, search, album_id, storage_type):
         """
             Add a new album to view
-            @param local_search as LocalSearch
+            @param search as *Search
             @param artist_id as int
             @param storage_type as StorageType
         """
         if storage_type & StorageType.SEARCH:
+            artist_match = False
             album = Album(album_id)
-            self.__stack.current_child.albums_line_view.show()
-            self.__stack.current_child.albums_line_view.add_album(album)
-            self.show_placeholder(False)
+            if album.artists:
+                artist = sql_escape(album.artists[0])
+                search = sql_escape(self.__current_search)
+                artist_match = artist.find(search) != -1
+            if artist_match:
+                self._on_match_artist(search,
+                                      album.artist_ids[0],
+                                      storage_type)
+            else:
+                self.__stack.current_child.albums_line_view.show()
+                self.__stack.current_child.albums_line_view.add_value(album)
+                self.show_placeholder(False)
 
-    def _on_match_track(self, local_search, track_id, storage_type):
+    def _on_match_track(self, search, track_id, storage_type):
         """
             Add a new track to view
-            @param local_search as LocalSearch
+            @param search as *Search
             @param track_id as int
             @param storage_type as StorageType
         """
@@ -284,12 +285,12 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
             self.__stack.current_child.search_tracks_view.append_row(track)
             self.show_placeholder(False)
 
-    def _on_search_finished(self, search_handler):
+    def _on_search_finished(self, search_handler, last):
         """
             Stop spinner and show placeholder if not result
             @param search_handler as LocalSearch/SpotifySearch
+            @param last as bool
         """
-        self.__searches_count -= 1
         tracks_len = len(
             self.__stack.current_child.search_tracks_view.children)
         albums_len = len(
@@ -298,11 +299,20 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
             self.__stack.current_child.artists_line_view.children)
         empty = albums_len == 0 and tracks_len == 0 and artists_len == 0
         self.__stack.set_visible_child(self.__stack.current_child)
-        if self.__searches_count == 0:
+        if last:
             self.__banner.spinner.stop()
             if empty:
                 self.show_placeholder(True, _("No results for this search"))
 
+    def _on_web_search_changed(self, settings, value):
+        """
+            Show/hide labels
+            @param settings as Gio.Settings
+            @param value as GLib.Variant
+        """
+        self.__search.set_web_search(
+            App().settings.get_value("web-search").get_string())
+
 #######################
 # PRIVATE             #
 #######################
@@ -312,29 +322,6 @@ class SearchView(View, Gtk.Bin, SignalsHelper):
         """
         self.__placeholder.set_text()
 
-    def __on_search_get(self, result, search, storage_type):
-        """
-            Add rows for internal results
-            @param result as [(int, Album, bool)]
-        """
-        if result:
-            albums = []
-            reveal_albums = []
-            for (album, in_tracks) in result:
-                albums.append(album)
-                if in_tracks:
-                    reveal_albums.append(album)
-            self.__view.add_reveal_albums(reveal_albums)
-            self.__view.populate(albums)
-            self.show_placeholder(False)
-
-        if storage_type & StorageType.EPHEMERAL:
-            App().task_helper.run(App().spotify.search,
-                                  search,
-                                  self.__cancellable)
-        else:
-            self._on_search_finished()
-
     def _on_search_changed(self, widget):
         """
             Timeout filtering
