@@ -28,10 +28,9 @@ class AlbumsDecadeWidget(RoundedAlbumsWidget):
             @param view_type as ViewType
             @param font_height as int
         """
-        self.__font_height = font_height
         decade_str = "%s - %s" % (item_ids[0], item_ids[-1])
         RoundedAlbumsWidget.__init__(self, item_ids, decade_str,
-                                     decade_str, view_type)
+                                     decade_str, view_type, font_height)
         self._genre = Type.YEARS
 
     def populate(self):
@@ -43,15 +42,6 @@ class AlbumsDecadeWidget(RoundedAlbumsWidget):
         else:
             self.set_artwork()
 
-    def set_view_type(self, view_type):
-        """
-            Update view type
-            @param view_type as ViewType
-        """
-        RoundedAlbumsWidget.set_view_type(self, view_type)
-        self.set_size_request(self._art_size,
-                              self._art_size + self.__font_height)
-
     @property
     def artwork_name(self):
         """
