@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -16,7 +16,7 @@ from gettext import gettext as _
 
 from lollypop.logger import Logger
 from lollypop.utils import emit_signal
-from lollypop.define import App, ArtSize, ArtBehaviour, ViewType
+from lollypop.define import App, ArtSize, ArtBehaviour
 from lollypop.helper_signals import SignalsHelper, signals_map
 
 
@@ -54,10 +54,11 @@ class ArtworkSearchChild(Gtk.FlowBoxChild):
         self.__image.set_property("valign", Gtk.Align.CENTER)
         self.add(grid)
 
-    def populate(self, bytes):
+    def populate(self, bytes, art_size):
         """
             Populate images with bytes
             @param bytes as bytes
+            @param art_size as int
             @return bool if success
         """
         try:
@@ -77,17 +78,19 @@ class ArtworkSearchChild(Gtk.FlowBoxChild):
                 pixbuf = App().art.load_behaviour(
                                                 pixbuf,
                                                 None,
-                                                ArtSize.BANNER * scale_factor,
-                                                ArtSize.BANNER * scale_factor,
+                                                art_size * scale_factor,
+                                                art_size * scale_factor,
                                                 ArtBehaviour.CROP)
                 stream.close()
-            self.__bytes = bytes
-            surface = Gdk.cairo_surface_create_from_pixbuf(
-                                                   pixbuf,
-                                                   scale_factor,
-                                                   None)
-            self.__image.set_from_surface(surface)
-            return True
+                self.__bytes = bytes
+                surface = Gdk.cairo_surface_create_from_pixbuf(
+                                                       pixbuf,
+                                                       scale_factor,
+                                                       None)
+                del pixbuf
+                self.__image.set_from_surface(surface)
+                del surface
+                return True
         except Exception as e:
             Logger.error("ArtworkSearch::__get_image: %s" % e)
         return False
@@ -113,7 +116,7 @@ class ArtworkSearchWidget(Gtk.Grid, SignalsHelper):
             @param view_type as ViewType
         """
         Gtk.Grid.__init__(self)
-        self._view_type = view_type
+        self.__view_type = view_type
         self.__timeout_id = None
         self.__uri_artwork_id = None
         self.__uris = []
@@ -140,9 +143,11 @@ class ArtworkSearchWidget(Gtk.Grid, SignalsHelper):
         self.__label = builder.get_object("label")
         self.__label.set_text(_("Select artwork"))
 
-        if self._view_type & ViewType.ADAPTIVE:
+        if App().window.folded:
+            self._art_size = ArtSize.MEDIUM
             widget.add(self._flowbox)
         else:
+            self._art_size = ArtSize.BANNER
             scrolled = Gtk.ScrolledWindow.new()
             scrolled.show()
             scrolled.set_size_request(700, 400)
@@ -169,14 +174,14 @@ class ArtworkSearchWidget(Gtk.Grid, SignalsHelper):
             grid.set_row_spacing(5)
             image = Gtk.Image.new_from_icon_name("edit-clear-all-symbolic",
                                                  Gtk.IconSize.INVALID)
-            image.set_pixel_size(ArtSize.MEDIUM)
+            image.set_pixel_size(self._art_size)
             context = image.get_style_context()
             context.add_class("cover-frame")
             padding = context.get_padding(Gtk.StateFlags.NORMAL)
             border = context.get_border(Gtk.StateFlags.NORMAL)
-            image.set_size_request(ArtSize.BANNER + padding.left +
+            image.set_size_request(self._art_size + padding.left +
                                    padding.right + border.left + border.right,
-                                   ArtSize.BANNER + padding.top +
+                                   self._art_size + padding.top +
                                    padding.bottom + border.top + border.bottom)
             image.show()
             label = Gtk.Label.new(_("Remove"))
@@ -196,6 +201,14 @@ class ArtworkSearchWidget(Gtk.Grid, SignalsHelper):
         """
         self._cancellable.cancel()
 
+    @property
+    def view_type(self):
+        """
+            Get view type
+            @return ViewType
+        """
+        return self.__view_type
+
 #######################
 # PROTECTED           #
 #######################
@@ -254,7 +267,7 @@ class ArtworkSearchWidget(Gtk.Grid, SignalsHelper):
         """
             Load content in view
             @param art as Art
-            @param uris as (str, str)
+            @param uris as (str, str)/None
         """
         if uris:
             (uri, api) = uris.pop(0)
@@ -294,9 +307,9 @@ class ArtworkSearchWidget(Gtk.Grid, SignalsHelper):
             @param content as bytes
             @param api as str
         """
-        child = ArtworkSearchChild(api, self._view_type)
+        child = ArtworkSearchChild(api, self.__view_type)
         child.show()
-        status = child.populate(content)
+        status = child.populate(content, self._art_size)
         if status:
             child.set_name("web")
             self._flowbox.add(child)
