@@ -17,7 +17,7 @@ from random import choice
 
 from lollypop.utils import set_cursor_type, on_query_tooltip, popup_widget
 from lollypop.utils_artist import add_artist_to_playback, play_artists
-from lollypop.define import App, ArtSize, ArtBehaviour, ViewType, Size
+from lollypop.define import App, ArtSize, ArtBehaviour, ViewType
 from lollypop.widgets_banner import BannerWidget
 from lollypop.helper_signals import SignalsHelper, signals_map
 
@@ -44,6 +44,7 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
         builder.add_from_resource("/org/gnome/Lollypop/ArtistBannerWidget.ui")
         builder.connect_signals(self)
         self.__badge_artwork = builder.get_object("badge_artwork")
+        self.__labels = builder.get_object("label_event")
         self.__title_label = builder.get_object("artist")
         self.__title_label.connect("realize", set_cursor_type)
         self.__title_label.connect("query-tooltip", on_query_tooltip)
@@ -55,9 +56,8 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
             self.__menu_button.hide()
         builder.get_object("artwork_event").connect(
             "realize", set_cursor_type)
-        builder.get_object("label_event").connect(
-            "realize", set_cursor_type)
-        widget = builder.get_object("widget")
+        self.__labels.connect("realize", set_cursor_type)
+        self.__widget = builder.get_object("widget")
         artists = []
         for artist_id in self.__artist_ids:
             artists.append(App().artists.get_name(artist_id))
@@ -65,10 +65,13 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
             ", ".join(artists)))
         self.__show_artwork = len(artist_ids) == 1
         self.__title_label.get_style_context().add_class("text-x-large")
-        self._overlay.add_overlay(widget)
-        self._overlay.set_overlay_pass_through(widget, True)
+        self._overlay.add_overlay(self.__widget)
+        self._overlay.set_overlay_pass_through(self.__widget, True)
         self.__update_add_button()
+        self.__set_internal_size()
         return [
+               (App().window.container.widget, "notify::folded",
+                "_on_container_folded"),
                (App().art, "artist-artwork-changed",
                 "_on_artist_artwork_changed"),
                (App().player, "playback-added", "_on_playback_changed"),
@@ -87,7 +90,6 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
         """
         BannerWidget.update_for_width(self, width)
         self.__set_artwork()
-        self.__set_internal_size()
 
 #######################
 # PROTECTED           #
@@ -99,7 +101,14 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
         """
         if BannerWidget._handle_width_allocate(self, allocation):
             self.__set_artwork()
-            self.__set_internal_size()
+
+    def _on_container_folded(self, leaflet, folded):
+        """
+            Handle libhandy folded status
+            @param leaflet as Handy.Leaflet
+            @param folded as Gparam
+        """
+        self.__set_internal_size()
 
     def _on_artist_artwork_setting_changed(self, settings, variant):
         """
@@ -148,13 +157,13 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
         menu = ArtistMenu(self.__artist_ids[0],
                           self.__storage_type,
                           self.view_type,
-                          App().window.is_adaptive)
+                          App().window.folded)
         menu_widget = MenuBuilder(menu, False)
         menu_widget.show()
         menu_ext = SimilarsMenu(self.__artist_ids[0])
         menu_ext.show()
         menu_widget.add_widget(menu_ext)
-        if self.view_type & ViewType.ADAPTIVE:
+        if App().window.folded:
             menu_ext2 = ArtistArtworkMenu(self.__artist_ids[0],
                                           self.view_type,
                                           True)
@@ -172,7 +181,7 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
         from lollypop.widgets_menu import MenuBuilder
         from lollypop.menu_artwork import ArtistArtworkMenu
         menu = Gio.Menu()
-        if App().window.is_adaptive:
+        if App().window.folded:
             from lollypop.menu_header import ArtistMenuHeader
             menu.append_item(ArtistMenuHeader(self.__artist_ids[0]))
         menu_widget = MenuBuilder(menu, False)
@@ -209,7 +218,7 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
 # PRIVATE             #
 #######################
     def __close_artwork_menu(self, action, variant):
-        if App().window.is_adaptive:
+        if App().window.folded:
             App().window.container.go_back()
         else:
             self.__artwork_popup.destroy()
@@ -231,6 +240,13 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
                                         self._on_artwork)
         else:
             self._artwork.get_style_context().add_class("default-banner")
+        if self.width < ArtSize.BANNER * 3:
+            if self.__widget.get_child_at(1, 0) == self.__labels:
+                self.__widget.remove(self.__labels)
+                self.__widget.attach(self.__labels, 2, 2, 3, 1)
+        elif self.__widget.get_child_at(2, 2) == self.__labels:
+            self.__widget.remove(self.__labels)
+            self.__widget.attach(self.__labels, 1, 0, 1, 3)
 
     def __set_badge_artwork(self, art_size):
         """
@@ -261,21 +277,14 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
         title_context = self.__title_label.get_style_context()
         for c in title_context.list_classes():
             title_context.remove_class(c)
-        if self.width <= Size.SMALL:
-            art_size = None
-            cls = "text-medium"
-        elif self.width <= Size.MEDIUM:
+        if App().window.folded:
             art_size = ArtSize.MEDIUM
             cls = "text-large"
         else:
             art_size = ArtSize.BANNER
-            cls = "text-xx-large"
+            cls = "text-x-large"
         self.__title_label.get_style_context().add_class(cls)
-        if art_size is None:
-            self.__badge_artwork.hide()
-        else:
-            self.__badge_artwork.show()
-            self.__set_badge_artwork(art_size)
+        self.__set_badge_artwork(art_size)
 
     def __update_add_button(self):
         """
@@ -304,8 +313,6 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
             @param surface as cairo.Surface
             @param art_size as int
         """
-        if self.get_allocated_width() >= Size.MEDIUM / 1.5:
-            self.__badge_artwork.show()
         if surface is None:
             self.__badge_artwork.get_style_context().add_class("circle-icon")
             self.__badge_artwork.set_size_request(art_size, art_size)
