@@ -38,13 +38,14 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
         """
         Gtk.Stack.__init__(self)
         self.__built = False
-        self.__boxes = {}
+        self.__grids = {}
         self.__menu_queue = []
         self.__submenu_queue = []
         self.__widgets_queue = []
         self.__add_menu(menu, "main", False, scrolled)
         return [
-            (App().window, "adaptive-changed", "_on_adaptive_changed")
+            (App().window.container.widget, "notify::folded",
+             "_on_container_folded")
         ]
 
     def add_widget(self, widget, position=-1):
@@ -60,13 +61,13 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
 #######################
 # PROTECTED           #
 #######################
-    def _on_adaptive_changed(self, window, status):
+    def _on_container_folded(self, leaflet, folded):
         """
             Destroy self if adaptive off
-            @param window as Window
-            @param status as bool
+            @param leaflet as Handy.Leaflet
+            @param folded as Gparam
         """
-        if not status:
+        if not App().window.folded:
             self.destroy()
 
 #######################
@@ -80,18 +81,18 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
             (widget, position) = self.__widgets_queue.pop(0)
             if widget.submenu_name is not None:
                 self.__add_menu_container(widget.submenu_name, True, True)
-                self.__boxes[widget.submenu_name].add(widget)
+                self.__grids[widget.submenu_name].add(widget)
                 button = Gtk.ModelButton.new()
                 button.set_label(widget.submenu_name)
                 button.get_child().set_halign(Gtk.Align.START)
                 button.set_property("menu-name", widget.submenu_name)
                 button.show()
-                parent = self.__boxes["main"]
+                parent = self.__grids["main"]
                 widget = button
             else:
                 parent = self.get_child_by_name("main")
                 if isinstance(parent, Gtk.ScrolledWindow):
-                    # scrolled -> viewport -> box
+                    # scrolled -> viewport -> grid
                     parent = parent.get_child().get_child()
             if position < -1:
                 position = len(parent) + position + 1
@@ -100,30 +101,31 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
             else:
                 parent.add(widget)
 
-    def __add_menu_container(self, menu_name, submenu, scrolled):
+    def __add_menu_container(self, menu_name, submenu, scrolled, margin=10):
         """
             Add menu container
             @param menu_name as str
             @param submenu as bool
             @param scrolled as bool
+            @param margin as int
         """
-        box = self.get_child_by_name(menu_name)
-        if box is None:
-            box = Gtk.Grid.new()
-            box.set_orientation(Gtk.Orientation.VERTICAL)
-            box.connect("map", self.__on_box_map, menu_name)
-            self.__boxes[menu_name] = box
-            box.set_property("margin", 10)
-            box.show()
+        grid = self.get_child_by_name(menu_name)
+        if grid is None:
+            grid = Gtk.Grid.new()
+            grid.set_orientation(Gtk.Orientation.VERTICAL)
+            grid.connect("map", self.__on_grid_map, menu_name)
+            self.__grids[menu_name] = grid
+            grid.set_property("margin", margin)
+            grid.show()
             if scrolled:
                 scrolled = Gtk.ScrolledWindow()
                 scrolled.set_policy(Gtk.PolicyType.NEVER,
                                     Gtk.PolicyType.AUTOMATIC)
                 scrolled.show()
-                scrolled.add(box)
+                scrolled.add(grid)
                 self.add_named(scrolled, menu_name)
             else:
-                self.add_named(box, menu_name)
+                self.add_named(grid, menu_name)
             if submenu:
                 button = Gtk.ModelButton.new()
                 button.get_style_context().add_class("padding")
@@ -132,7 +134,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
                 button.set_label(menu_name)
                 button.get_child().set_halign(Gtk.Align.START)
                 button.show()
-                box.add(button)
+                grid.add(button)
 
     def __add_menu(self, menu, menu_name, submenu, scrolled):
         """
@@ -142,12 +144,18 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
             @param submenu as bool
             @param scrolled as bool
         """
-        self.__add_menu_container(menu_name, submenu, scrolled)
-        menu_range = list(range(0, menu.get_n_items()))
-        if submenu:
-            self.__submenu_queue.append((menu, menu_name, menu_range))
+        n_items = menu.get_n_items()
+        if n_items:
+            self.__add_menu_container(menu_name, submenu, scrolled, 10)
+            menu_range = list(range(0, n_items))
+            if submenu:
+                self.__submenu_queue.append((menu, menu_name, menu_range))
+            else:
+                self.__add_menu_items(menu, menu_name, menu_range)
         else:
-            self.__add_menu_items(menu, menu_name, menu_range)
+            self.__add_menu_container(menu_name, submenu, scrolled, 0)
+            self.__built = True
+            self.__add_widgets()
 
     def __add_menu_items(self, menu, menu_name, indexes):
         """
@@ -234,7 +242,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
         if target is not None:
             button.set_action_target_value(target)
         button.show()
-        self.__boxes[menu_name].add(button)
+        self.__grids[menu_name].add(button)
 
     def __add_section(self, text, menu, menu_name):
         """
@@ -250,7 +258,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
         box.add(sep1)
         label = Gtk.Label.new(text.get_string())
         label.get_style_context().add_class("dim-label")
-        if App().window.is_adaptive:
+        if App().window.folded:
             label.get_style_context().add_class("padding")
         box.add(label)
         sep2 = Gtk.Separator.new(Gtk.Orientation.HORIZONTAL)
@@ -258,7 +266,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
         sep2.set_hexpand(True)
         box.add(sep2)
         box.show_all()
-        self.__boxes[menu_name].add(box)
+        self.__grids[menu_name].add(box)
         self.__add_menu(menu, menu_name, False, False)
 
     def __add_submenu(self, text, menu, menu_name):
@@ -276,7 +284,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
         button.set_label(text.get_string())
         button.get_child().set_halign(Gtk.Align.START)
         button.show()
-        self.__boxes[menu_name].add(button)
+        self.__grids[menu_name].add(button)
 
     def __add_header(self, text, icon_name, menu_name):
         """
@@ -307,7 +315,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
         grid.add(close_image)
         button.set_image(grid)
         button.get_style_context().add_class("padding")
-        self.__boxes[menu_name].add(button)
+        self.__grids[menu_name].add(button)
 
     def __add_album_header(self, text, album_id, menu_name):
         """
@@ -344,7 +352,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
                 ArtBehaviour.CACHE | ArtBehaviour.CROP_SQUARE,
                 self.__on_artwork,
                 artwork)
-        self.__boxes[menu_name].add(button)
+        self.__grids[menu_name].add(button)
 
     def __add_artist_header(self, text, artist_id, menu_name):
         """
@@ -383,7 +391,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
                 ArtBehaviour.ROUNDED,
                 self.__on_artwork,
                 artwork)
-        self.__boxes[menu_name].add(button)
+        self.__grids[menu_name].add(button)
 
     def __add_rounded_header(self, text, artwork_name, menu_name):
         """
@@ -431,7 +439,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
                 "ROUNDED",
                 ArtSize.BANNER, ArtSize.BANNER,
                 callback=(on_load_from_cache, artwork))
-        self.__boxes[menu_name].add(button)
+        self.__grids[menu_name].add(button)
 
     def __on_artwork(self, surface, artwork):
         """
@@ -446,7 +454,7 @@ class MenuBuilder(Gtk.Stack, SignalsHelper):
             artwork.set_from_surface(surface)
         artwork.show()
 
-    def __on_box_map(self, widget, menu_name):
+    def __on_grid_map(self, widget, menu_name):
         """
             On map, set stack order
             @param widget as Gtk.Widget
