@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -12,16 +12,18 @@
 
 from random import sample
 
+from lollypop.helper_signals import SignalsHelper, signals_map
 from lollypop.define import App, Type
 from lollypop.objects_track import Track
 from lollypop.widgets_albums_rounded import RoundedAlbumsWidget
 
 
-class PlaylistRoundedWidget(RoundedAlbumsWidget):
+class PlaylistRoundedWidget(RoundedAlbumsWidget, SignalsHelper):
     """
         Playlist widget showing cover for 4 albums
     """
 
+    @signals_map
     def __init__(self, playlist_id, view_type, font_height):
         """
             Init widget
@@ -29,12 +31,14 @@ class PlaylistRoundedWidget(RoundedAlbumsWidget):
             @param view_type as ViewType
             @param font_height as int
         """
-        self.__font_height = font_height
         name = sortname = App().playlists.get_name(playlist_id)
         RoundedAlbumsWidget.__init__(self, playlist_id, name,
-                                     sortname, view_type)
+                                     sortname, view_type, font_height)
         self._track_ids = []
         self._genre = Type.PLAYLISTS
+        return [
+            (App().art, "artwork-cleared", "_on_artwork_cleared")
+        ]
 
     def populate(self):
         """
@@ -45,15 +49,6 @@ class PlaylistRoundedWidget(RoundedAlbumsWidget):
         else:
             self.set_artwork()
 
-    def set_view_type(self, view_type):
-        """
-            Update view type
-            @param view_type as ViewType
-        """
-        RoundedAlbumsWidget.set_view_type(self, view_type)
-        self.set_size_request(self._art_size,
-                              self._art_size + self.__font_height)
-
     @property
     def track_ids(self):
         """
@@ -94,6 +89,16 @@ class PlaylistRoundedWidget(RoundedAlbumsWidget):
                 break
         return album_ids
 
+    def _on_artwork_cleared(self, art, name, prefix):
+        """
+            Update artwork
+            @param art as Art
+            @param name as str
+            @param prefix as str
+        """
+        if self._artwork is not None:
+            self.set_artwork()
+
 #######################
 # PRIVATE             #
 #######################
